
drop table security.entity_rule;

create table security.entity_rule (
	rule_id INT NOT NULL,
	entity_name VARCHAR(100) NOT NULL,
	eventtypes VARCHAR(255)
)
extent size 16 next size 16
lock mode page;

alter table 'SECURITY'.entity_rule add constraint primary key 
	(rule_id)
	constraint entity_rule;

ALTER TABLE 'SECURITY'.entity_rule ADD CONSTRAINT foreign key
	(rule_id)
	references 'SECURITY'.rule
	(id)
	on delete cascade
	constraint mdm_sec_entity_rule_fk1;

drop table mdmschema.location;
drop table mdmschema.location_hierarchy;
drop table mdmschema.location_hierarchy_node;
drop table mdmschema.product;
drop table mdmschema.product_hierarchy;
drop table mdmschema.product_hierarchy_node;
drop table mdmschema.category;
drop table mdmschema.location_set;
drop table mdmschema.location_set_entry;
drop table mdmschema.product_set;
drop table mdmschema.product_set_entry;


create table eventschema.event_type (
	id INT NOT NULL,
	type VARCHAR(50) NOT NULL
)
extent size 16 next size 16
lock mode row;

alter table eventschema.event_type add constraint primary key 
	(id)
	constraint event_type;

create table mdmschema.entity (
	internal_id SERIAL NOT NULL,
	name VARCHAR(100) NOT NULL
)
extent size 16 next size 16
lock mode page;

alter table mdmschema.entity add constraint primary key 
	(internal_id)
	constraint entity;

create table mdmschema.mdmset (
	internal_id SERIAL NOT NULL,
	external_id VARCHAR(255) NOT NULL,
	type_id INT NOT NULL,
	tstamp DATETIME YEAR TO FRACTION(3) NOT NULL
)
extent size 16 next size 16
lock mode page;

alter table mdmschema.mdmset add constraint primary key 
	(internal_id)
	constraint mdmset;

ALTER TABLE mdmschema.mdmset ADD CONSTRAINT foreign key
	(type_id)
	references mdmschema.entity
	(internal_id)
	on delete cascade
	constraint mdm_mdmset_fk1;

create table mdmschema.set_entry (
	entry_id INT NOT NULL,
	set_id INT NOT NULL,
	vocabulary_id INT
)
extent size 16 next size 16
lock mode page;

alter table 'MDMSCHEMA'.set_entry add constraint primary key 
	(entry_id, set_id)
	constraint set_entry;

ALTER TABLE mdmschema.set_entry ADD CONSTRAINT foreign key
	(set_id)
	references mdmschema.mdmset
	(internal_id)
	on delete cascade
	constraint mdm_set_entry_fk1;

ALTER TABLE mdmschema.set_entry ADD CONSTRAINT foreign key
	(vocabulary_id)
	references mdmschema.vocabulary
	(internal_id)
	on delete cascade
	constraint mdm_set_entry_fk2;


create table mdmschema.hierarchy_node (
	internal_id SERIAL NOT NULL,
	entry_id INT,
	node node,
	vocabulary_id INT
)
extent size 16 next size 16
lock mode page;

alter table mdmschema.hierarchy_node add constraint primary key 
	(internal_id)
	constraint hierarchy_node;

ALTER TABLE mdmschema.hierarchy_node ADD CONSTRAINT foreign key
	(vocabulary_id)
	references mdmschema.vocabulary
	(internal_id)
	on delete cascade
	constraint mdm_hierarchy_node_fk1;

create table mdmschema.hierarchy (
	internal_id SERIAL NOT NULL,
	root_node INT NOT NULL,
	external_id VARCHAR(255) NOT NULL,
	type_id INT NOT NULL,
	tstamp DATETIME YEAR TO FRACTION(3) NOT NULL
)
extent size 16 next size 16
lock mode page;

alter table 'MDMSCHEMA'.hierarchy add constraint primary key 
	(internal_id)
	constraint hierarchy;

ALTER TABLE mdmschema.hierarchy ADD CONSTRAINT foreign key
	(type_id)
	references mdmschema.entity
	(internal_id)
	on delete cascade
	constraint mdm_hierarchy_fk1;


ALTER TABLE mdmschema.hierarchy ADD CONSTRAINT foreign key
	(root_node)
	references mdmschema.hierarchy_node
	(internal_id)
	on delete cascade
	constraint mdm_hierarchy_fk2;	


drop table mdmschema.vocabulary;

create table 'MDMSCHEMA'.vocabulary (
	internal_id SERIAL not null,
	external_id VARCHAR(255) not null,
	type_id INT
)
extent size 16 next size 16
lock mode page;

alter table 'MDMSCHEMA'.vocabulary add constraint primary key 
	(internal_id)
	constraint vocabulary;

ALTER TABLE 'MDMSCHEMA'.vocabulary ADD CONSTRAINT foreign key
	(type_id)
	references mdmschema.entity
	(internal_id)
	on delete cascade
	constraint mdm_vocabulary_fk1;

drop table mdmschema.vocabulary_element;

create table mdmschema.vocabulary_element (
	internal_id SERIAL NOT NULL,
	element_name VARCHAR(255) NOT NULL,
	vocabulary_id INT NOT NULL,
	tstamp DATETIME YEAR TO FRACTION(3) NOT NULL,
	xml_element clob
)
extent size 16 next size 16
lock mode page;

alter table mdmschema.vocabulary_element add constraint primary key 
	(internal_id)
	constraint vocabulary_element;

ALTER TABLE mdmschema.vocabulary_element ADD CONSTRAINT foreign key
	(vocabulary_id)
	references mdmschema.vocabulary
	(internal_id)
	on delete cascade
	constraint mdm_vocabulary_element_fk1;

delete from 'SECURITY'.rule_attribute;
delete from 'SECURITY'.rule;
delete from 'SECURITY'.policy;
delete from 'SECURITY'.entity_attribute;

delete from 'MDMSCHEMA'.location_attribs;
delete from 'MDMSCHEMA'.product_attribs;
delete from 'MDMSCHEMA'.vocabulary_element_attribs;

GRANT SELECT ON mdmschema.mdmset TO viewschema, securedview WITH GRANT OPTION AS mdmschema;
GRANT SELECT ON mdmschema.entity TO viewschema, securedview WITH GRANT OPTION AS mdmschema;
GRANT SELECT ON mdmschema.set_entry TO viewschema, securedview WITH GRANT OPTION AS mdmschema;
GRANT SELECT ON mdmschema.hierarchy_node TO viewschema, securedview WITH GRANT OPTION AS mdmschema;
GRANT SELECT ON mdmschema.hierarchy TO viewschema, securedview WITH GRANT OPTION AS mdmschema;
GRANT SELECT ON mdmschema.vocabulary TO viewschema, securedview WITH GRANT OPTION AS mdmschema;
GRANT SELECT ON mdmschema.vocabulary_element TO viewschema, securedview WITH GRANT OPTION AS mdmschema;
GRANT SELECT ON eventschema.event_type TO viewschema, securedview WITH GRANT OPTION AS eventschema;


create view "VIEWSCHEMA".children (hierarchy_id,hierarchy,hierarchy_type,
       parent_node_id,parent_internal_id,parent_vocabulary,child_node_id,
       child_internal_id,child_vocabulary) as
   select x3.internal_id ,x3.external_id ,x3.type_id ,x0.internal_id ,
       x0.entry_id ,x0.vocabulary_id ,x1.internal_id ,x1.entry_id ,
       x1.vocabulary_id 
   from "MDMSCHEMA".hierarchy_node x0 ,"MDMSCHEMA".hierarchy_node x1 ,"MDMSCHEMA".hierarchy_node x2 ,"MDMSCHEMA".hierarchy x3 
   where (((x2.internal_id = x3.root_node ) AND ((x0.internal_id = x2.internal_id ) OR ("informix".isancestor(x2.node ,x0.node )) ) ) AND ("informix".isparent(x0.node ,x1.node )) ) ;

create view "VIEWSCHEMA".descendants (hierarchy_id,hierarchy,
       hierarchy_type,ancestor_node_id,ancestor_internal_id,ancestor_vocabulary,
       descendant_node_id,descendant_internal_id,descendant_vocabulary) as
   select x3.internal_id ,x3.external_id ,x3.type_id ,x0.internal_id ,
       x0.entry_id ,x0.vocabulary_id ,x1.internal_id ,x1.entry_id ,
       x1.vocabulary_id 
   from "MDMSCHEMA".hierarchy_node x0 ,"MDMSCHEMA".hierarchy_node x1 ,"MDMSCHEMA".hierarchy_node x2 ,"MDMSCHEMA".hierarchy x3 
   where (((x2.internal_id = x3.root_node ) AND ((x0.internal_id = x2.internal_id ) OR ("informix".isancestor(x2.node ,x0.node )) ) ) AND ("informix".isancestor(x0.node ,x1.node )) ) ;

create view "VIEWSCHEMA".location_children (hierarchy_id,hierarchy,
       hierarchy_type,parent_node_id,parent_internal_id,parent_vocabulary,
       child_node_id,child_internal_id,child_vocabulary) as
   select x0.hierarchy_id ,x0.hierarchy ,x0.hierarchy_type ,
       x0.parent_node_id ,x0.parent_internal_id ,x0.parent_vocabulary ,
       x0.child_node_id ,x0.child_internal_id ,x0.child_vocabulary 
   from "VIEWSCHEMA".children x0 ,"MDMSCHEMA".entity x1 
   where ((x0.hierarchy_type = x1.internal_id ) AND (x1.name = 'Location' ) ) ;

create view "VIEWSCHEMA".product_children (hierarchy_id,hierarchy,
       hierarchy_type,parent_node_id,parent_internal_id,parent_vocabulary,
       child_node_id,child_internal_id,child_vocabulary) as
   select x0.hierarchy_id ,x0.hierarchy ,x0.hierarchy_type ,
       x0.parent_node_id ,x0.parent_internal_id ,x0.parent_vocabulary ,
       x0.child_node_id ,x0.child_internal_id ,x0.child_vocabulary 
   from "VIEWSCHEMA".children x0 ,"MDMSCHEMA".entity x1 
   where ((x0.hierarchy_type = x1.internal_id ) AND (x1.name = 'Product' ) ) ;

create view "VIEWSCHEMA".location_descendants (hierarchy_id,hierarchy,
       hierarchy_type,ancestor_node_id,ancestor_internal_id,ancestor_vocabulary,
       descendant_node_id,descendant_internal_id,descendant_vocabulary) as
   select x0.hierarchy_id ,x0.hierarchy ,x0.hierarchy_type ,
       x0.ancestor_node_id ,x0.ancestor_internal_id ,x0.ancestor_vocabulary ,
       x0.descendant_node_id ,x0.descendant_internal_id ,x0.descendant_vocabulary 
   from "VIEWSCHEMA".descendants x0 ,"MDMSCHEMA".entity x1 
   where ((x0.hierarchy_type = x1.internal_id ) AND (x1.name = 'Location' ) ) ;

create view "VIEWSCHEMA".product_descendants (hierarchy_id,hierarchy,
       hierarchy_type,ancestor_node_id,ancestor_internal_id,ancestor_vocabulary,
       descendant_node_id,descendant_internal_id,descendant_vocabulary) as
   select x0.hierarchy_id ,x0.hierarchy ,x0.hierarchy_type ,
       x0.ancestor_node_id ,x0.ancestor_internal_id ,x0.ancestor_vocabulary ,
       x0.descendant_node_id ,x0.descendant_internal_id ,x0.descendant_vocabulary 
   from "VIEWSCHEMA".descendants x0 ,"MDMSCHEMA".entity x1 
   where ((x0.hierarchy_type = x1.internal_id ) AND (x1.name = 'Product' ) ) ;

CREATE VIEW "VIEWSCHEMA".vocabulary_element AS
SELECT ve.internal_id, ve.element_name AS name, ve.vocabulary_id, v.external_id , e.name AS vocabulary
FROM mdmschema.vocabulary_element ve, mdmschema.vocabulary v, mdmschema.entity e 
WHERE ve.vocabulary_id = v.internal_id and v.type_id = e.internal_id;
