CREATE TABLE alerts.alert (
	id SERIAL NOT NULL,
	classname VARCHAR(254) NOT NULL,
	enabled INTEGER NOT NULL
);

ALTER TABLE alerts.alert ADD CONSTRAINT (
	PRIMARY KEY (id)
	CONSTRAINT alerts_a_pk
);

CREATE TABLE alerts.delivery_method (
	id SERIAL NOT NULL,
	classname VARCHAR(254) NOT NULL,
	enabled INTEGER NOT NULL
);

ALTER TABLE alerts.delivery_method ADD CONSTRAINT (
	PRIMARY KEY (id)
	CONSTRAINT alerts_dm_pk
);

CREATE TABLE alerts.notification_configuration (
	id SERIAL NOT NULL,
	content CLOB NOT NULL,
	enabled INTEGER NOT NULL
);

ALTER TABLE alerts.notification_configuration ADD CONSTRAINT (
	PRIMARY KEY (id)
	CONSTRAINT alerts_nc_pk
);

CREATE TABLE alerts.subscription (
	id SERIAL NOT NULL,
	name VARCHAR(100) NOT NULL,
	description VARCHAR(255),
	subscriber VARCHAR(128) NOT NULL,
	alert_id INTEGER NOT NULL,
	notification_configuration_id INTEGER NOT NULL,
	enabled INTEGER NOT NULL,
	change_date DATETIME YEAR TO FRACTION
);

ALTER TABLE alerts.subscription ADD CONSTRAINT (
	PRIMARY KEY (id)
	CONSTRAINT alerts_s_pk
);

ALTER TABLE alerts.subscription ADD CONSTRAINT (
	FOREIGN KEY (alert_id)
	REFERENCES alerts.alert (id) 
	ON DELETE CASCADE
	CONSTRAINT alerts_s_fk1
);

ALTER TABLE alerts.subscription ADD CONSTRAINT (
	FOREIGN KEY (notification_configuration_id)
	REFERENCES alerts.notification_configuration (id) 
	ON DELETE CASCADE
	CONSTRAINT alerts_s_fk2
);

CREATE TABLE alerts.alert_parameter_values (
	subscription_id INTEGER NOT NULL,
	name VARCHAR(254) NOT NULL,
	value VARCHAR(254) NOT NULL
);

ALTER TABLE alerts.alert_parameter_values ADD CONSTRAINT (
	FOREIGN KEY (subscription_id)
	REFERENCES alerts.subscription (id) 
	ON DELETE CASCADE
	CONSTRAINT alerts_apv_fk
);

CREATE TABLE alerts.notification_configuration_parameter_values (
	subscription_id INTEGER NOT NULL,
	name VARCHAR(254) NOT NULL,
	value VARCHAR(254) NOT NULL
);

ALTER TABLE alerts.notification_configuration_parameter_values ADD CONSTRAINT (
	FOREIGN KEY (subscription_id)
	REFERENCES alerts.subscription (id) 
	ON DELETE CASCADE
	CONSTRAINT alerts_dmpv_fk
);

-- general RFIDIC admin tables.

CREATE TABLE rfidic.jars(
	jar_name VARCHAR(255) PRIMARY KEY,
	solution_name VARCHAR(255),	
	jar_location VARCHAR(255)
);


CREATE TABLE rfidic.locks(
	object_name VARCHAR(255) PRIMARY KEY
) LOCK MODE ROW;


CREATE TABLE UISCHEMA.databrowser_attributes (
		id VARCHAR(210) NOT NULL,
		attribname VARCHAR(255),
		attribvalue VARCHAR(255),
		attribtype VARCHAR(30),
		exttype INTEGER
	);


create table uischema.databrowser_filter (
       id VARCHAR(210) NOT NULL,
       username VARCHAR(150),
       security_id VARCHAR(100),
       filtername VARCHAR(200),
       description lvarchar(500),
       eventtype VARCHAR(50),
       filter_display lvarchar(4000),

       sort_by VARCHAR(80),
       sort_order VARCHAR(20)       
);


SET CONSTRAINTS ALL DEFERRED;

ALTER TABLE EVENTSCHEMA.document_xml ADD CONSTRAINT
  (FOREIGN KEY (document)
   REFERENCES eventschema.document_header(document_id) CONSTRAINT dhxml_document);

CREATE TABLE EVENTSCHEMA.temp ( eventId integer, attribute_path VARCHAR(255,0));

INSERT INTO EVENTSCHEMA.temp ( eventId, attribute_path) SELECT event_id, attribute_path from EVENTSCHEMA.event_surprize_attrs;

ALTER TABLE EVENTSCHEMA.event_surprize_attrs DROP (attribute_path);

ALTER TABLE EVENTSCHEMA.event_surprize_attrs ADD ( attribute_path VARCHAR(250,0) );

UPDATE EVENTSCHEMA.event_surprize_attrs set attribute_path=(SELECT attribute_path from EVENTSCHEMA.temp where eventId=EVENTSCHEMA.event_surprize_attrs.event_id);

ALTER TABLE EVENTSCHEMA.document_header_surprize_attrs MODIFY ( attribute_path VARCHAR(255
,0) NOT NULL );

DROP TABLE EVENTSCHEMA.temp;


SET CONSTRAINTS ALL IMMEDIATE;


commit;