CONNECT TO 'rfidic';

-- DDL Statements for table SERIALID.ENCODINGTYPE

CREATE TABLE SERIALID.ENCODINGTYPE  (
		  ENCODING_ID SMALLINT NOT NULL , 
		  ENCODING_NAME VARCHAR(15) NOT NULL 
		  ); 

-- DML TO INSERT SUPPORTING ENCODING

INSERT INTO SERIALID.ENCODINGTYPE VALUES(0,'SGTIN-96');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(0,'AI(01)+AI(21)');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(1,'SSCC-96');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(1,'SSCC-18');


-- DDL Statements for table SERIALID.RESOURCE
 
CREATE TABLE SERIALID.SID_RESOURCE  (
		  RESOURCE_ID SERIAL NOT NULL  , 
		  RESOURCE_IDENTIFIER VARCHAR(50) NOT NULL , 
		  ENCODING_TYPE SMALLINT NOT NULL , 
		  BLOCK_SIZE INT8 NOT NULL , 
		  THRESHOLD SMALLINT NOT NULL,
		  SERIALID_LENGTH SMALLINT NOT NULL,
		  NUMBER_SPACE_MULTIPLIER INTEGER, -- NEW COLUMN ADDED FOR DROP2
		  STATE SMALLINT ) -- NEW COLUMN ADDED FOR DROP2
LOCK MODE ROW; 	  


-- DDL Statements for primary key on Table SERIALID.RESOURCE

ALTER TABLE SERIALID.SID_RESOURCE 
	ADD CONSTRAINT PRIMARY KEY
		(RESOURCE_ID) CONSTRAINT PK_RESOURCE_ID;


-- DDL Statements for unique constraints on Table SERIALID.RESOURCE

ALTER TABLE SERIALID.SID_RESOURCE 
	ADD CONSTRAINT UNIQUE
		(RESOURCE_IDENTIFIER,
		 ENCODING_TYPE) CONSTRAINT UK_RESOURCE_ENCODING;

-- DDL Statements for table SERIALID.SERIALID_INVENTORY

CREATE TABLE SERIALID.SERIALID_INVENTORY  
(
	  RESOURCE_ID INTEGER NOT NULL , 
	  BLOCK_ID SERIAL NOT NULL  , 
	  LOWER_LIMIT INT8 NOT NULL , 
	  UPPER_LIMIT INT8 NOT NULL , 
	  AVAILABLE INT8 NOT NULL,
	  BLOCK_TYPE VARCHAR(10) NOT NULL
)
LOCK MODE ROW; 	  

-- DDL Statements for primary key on Table SERIALID.SERIALID_INVENTORY

ALTER TABLE SERIALID.SERIALID_INVENTORY 
	ADD CONSTRAINT PRIMARY KEY
		(BLOCK_ID) CONSTRAINT PK_BLOCK_ID;

ALTER TABLE SERIALID.SERIALID_INVENTORY MODIFY ( BLOCK_ID SERIAL (1));


-- DDL Statements for table SERIALID.REQUEST

CREATE TABLE SERIALID.REQUEST  (
		  REQUEST_ID SERIAL8 NOT NULL  , --CHANGE THE DATATYPE TO INT8
		  REQUEST_TIMESTAMP INT8  NOT NULL, 
		  REQUEST_SOURCE VARCHAR(10) NOT NULL , 
		  QUANTITY INT8,
		  STATE SMALLINT , -- NEW COLUMN ADDED FOR DROP2
		  RESOURCE_ID INTEGER,-- NEW COLUMN ADDED FOR DROP2
		  LOWER_LIMIT INT8,-- NEW COLUMN ADDED FOR DROP2
		  UPPER_LIMIT INT8,-- NEW COLUMN ADDED FOR DROP2
		  REQUEST_TYPE VARCHAR(10));-- NEW COLUMN ADDED FOR DROP2


-- DDL Statements for primary key on Table SERIALID.REQUEST

ALTER TABLE SERIALID.REQUEST 
	ADD CONSTRAINT PRIMARY KEY
		(REQUEST_ID) CONSTRAINT PK_REQUEST_ID ;


ALTER TABLE SERIALID.REQUEST MODIFY ( REQUEST_ID SERIAL8 (1));

--NEW CONSTRAINT ADDED FOR DROP2
ALTER TABLE SERIALID.REQUEST 
	ADD CONSTRAINT FOREIGN KEY
		(RESOURCE_ID)
	REFERENCES SERIALID.SID_RESOURCE
		(RESOURCE_ID) CONSTRAINT FK_RESOURCE_ID2;


-- INSERT A DUMMY REQUEST
INSERT INTO SERIALID.REQUEST(REQUEST_TIMESTAMP,REQUEST_SOURCE,QUANTITY) VALUES(123,'DUMMY',0);

-- DDL Statements for table SERIALID.SERIAL_ID

CREATE TABLE SERIALID.SERIAL_ID  (
		  RESOURCE_ID INTEGER NOT NULL , 
		  SERIAL_ID INT8 NOT NULL , 
		  STATUS INTEGER DEFAULT  0, 
		  REQUEST_ID INT8 DEFAULT 1)   
LOCK MODE ROW  ; 

CREATE INDEX SERIALID.RID_SID ON SERIALID.SERIAL_ID (SERIAL_ID,RESOURCE_ID,STATUS) ;


-- DDL Statements for foreign keys on Table SERIALID.SERIALID_INVENTORY

ALTER TABLE SERIALID.SERIALID_INVENTORY 
	ADD CONSTRAINT FOREIGN KEY
		(RESOURCE_ID)
	REFERENCES SERIALID.SID_RESOURCE
		(RESOURCE_ID) CONSTRAINT FK_RESOURCE_ID;
		
		
--DDL Statements for table SERIALID.EVENTSTORE
CREATE TABLE SERIALID.EVENTSTORE( EVENT_ID SERIAL8 NOT NULL , EVENTXML CLOB(1048576));	

ALTER TABLE SERIALID.EVENTSTORE 
	ADD CONSTRAINT PRIMARY KEY
		(EVENT_ID) CONSTRAINT PK_EVENT_ID ;


ALTER TABLE SERIALID.EVENTSTORE MODIFY ( EVENT_ID SERIAL8 (1));
	
		  