
-- CREATE USER 

CREATE USER SERIALID IDENTIFIED BY manager;

GRANT CREATE SESSION TO SERIALID; 

GRANT ALL PRIVILEGES TO SERIALID; 

-- DDL Statements for table SERIALID.ENCODINGTYPE

CREATE TABLE SERIALID.ENCODINGTYPE  (
		  ENCODING_ID NUMBER(1) NOT NULL , 
		  ENCODING_NAME VARCHAR2(15) NOT NULL 
		  ); 

-- DML TO INSERT SUPPORTING ENCODING

INSERT INTO SERIALID.ENCODINGTYPE VALUES(0,'SGTIN-96');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(0,'AI(01)+AI(21)');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(1,'SSCC-96');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(1,'SSCC-18');

-- DDL Statements for table SERIALID.RESOURCE
 
CREATE TABLE SERIALID.SID_RESOURCE (
		  RESOURCE_ID NUMBER(10) NOT NULL  , 
		  RESOURCE_IDENTIFIER VARCHAR2(50) NOT NULL , 
		  ENCODING_TYPE NUMBER(1) NOT NULL , 
		  BLOCK_SIZE NUMBER NOT NULL , 
		  THRESHOLD NUMBER(3) NOT NULL,
		  SERIALID_LENGTH NUMBER(3) NOT NULL,
		  NUMBER_SPACE_MULTIPLIER NUMBER(10), 
		  STATE NUMBER(1)); 

CREATE SEQUENCE SERIALID.RESOURCE___0
 START WITH     1
 INCREMENT BY   1
 NOCACHE
 NOCYCLE;


ALTER TABLE SERIALID.SID_RESOURCE 
	ADD CONSTRAINT PK_RESOURCE_ID PRIMARY KEY
		(RESOURCE_ID) ;


-- DDL Statements for unique constraints on Table SERIALID.RESOURCE

ALTER TABLE SERIALID.SID_RESOURCE 
	ADD CONSTRAINT UK_RESOURCE_ENCODING UNIQUE
		(RESOURCE_IDENTIFIER,
		 ENCODING_TYPE) ;

-- DDL Statements for table SERIALID.SERIALID_INVENTORY

CREATE TABLE SERIALID.SERIALID_INVENTORY  
(
	  RESOURCE_ID NUMBER(10)NOT NULL , 
	  BLOCK_ID NUMBER NOT NULL  , 
	  LOWER_LIMIT NUMBER NOT NULL , 
	  UPPER_LIMIT NUMBER NOT NULL , 
	  AVAILABLE NUMBER NOT NULL,
	  BLOCK_TYPE VARCHAR2(10) NOT NULL
); 	  


CREATE SEQUENCE SERIALID.BLOCK___0
 START WITH     1
 INCREMENT BY   1
 NOCACHE
 NOCYCLE;

 
-- DDL Statements for primary key on Table SERIALID.SERIALID_INVENTORY

ALTER TABLE SERIALID.SERIALID_INVENTORY 
	ADD CONSTRAINT PK_BLOCK_ID PRIMARY KEY
		(BLOCK_ID);


-- DDL Statements for table SERIALID.REQUEST

CREATE TABLE SERIALID.REQUEST  (
		  REQUEST_ID NUMBER NOT NULL  , 
		  REQUEST_TIMESTAMP NUMBER  NOT NULL, 
		  REQUEST_SOURCE VARCHAR2(10) NOT NULL , 
		  QUANTITY NUMBER,
		  STATE NUMBER(1) , 
		  RESOURCE_ID NUMBER(10),
		  LOWER_LIMIT NUMBER,
		  UPPER_LIMIT NUMBER,
		  REQUEST_TYPE VARCHAR2(10));

CREATE SEQUENCE SERIALID.REQUEST___0
 START WITH     2
 INCREMENT BY   1
 NOCACHE
 NOCYCLE;


-- DDL Statements for primary key on Table SERIALID.REQUEST

ALTER TABLE SERIALID.REQUEST 
	ADD CONSTRAINT PK_REQUEST_ID PRIMARY KEY
		(REQUEST_ID) ;


--NEW CONSTRAINT ADDED FOR DROP2
ALTER TABLE SERIALID.REQUEST 
	ADD CONSTRAINT FK_RESOURCE_ID2 FOREIGN KEY
		(RESOURCE_ID)
	REFERENCES SERIALID.SID_RESOURCE
		(RESOURCE_ID) ;


-- INSERT A DUMMY REQUEST
INSERT INTO SERIALID.REQUEST(REQUEST_ID,REQUEST_TIMESTAMP,REQUEST_SOURCE,QUANTITY) VALUES(1,123,'DUMMY',0);

-- DDL Statements for table SERIALID.SERIAL_ID

CREATE TABLE SERIALID.SERIAL_ID  (
		  RESOURCE_ID NUMBER(10)NOT NULL , 
		  SERIAL_ID NUMBER NOT NULL , 
		  STATUS NUMBER(1) DEFAULT  0, 
		  REQUEST_ID NUMBER DEFAULT 1); 


CREATE INDEX SERIALID.RID_SID ON SERIALID.SERIAL_ID (SERIAL_ID,RESOURCE_ID,STATUS) ;


-- DDL Statements for foreign keys on Table SERIALID.SERIALID_INVENTORY

ALTER TABLE SERIALID.SERIALID_INVENTORY 
	ADD CONSTRAINT FK_RESOURCE_ID FOREIGN KEY
		(RESOURCE_ID)
	REFERENCES SERIALID.SID_RESOURCE
		(RESOURCE_ID) ;
		
		
--DDL Statements for table SERIALID.EVENTSTORE
CREATE TABLE SERIALID.EVENTSTORE( EVENT_ID NUMBER NOT NULL , EVENTXML CLOB);	

CREATE SEQUENCE SERIALID.EVENTSTORE___0
 START WITH     1
 INCREMENT BY   1
 NOCACHE
 NOCYCLE;


ALTER TABLE SERIALID.EVENTSTORE 
	ADD CONSTRAINT PK_EVENT_ID PRIMARY KEY
		(EVENT_ID) ;	
