#! /bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title:	rfidic-env.sh
##   Description: Utility to migrate from RFIDIC 1.1 or 1.1.0.1 or 1.1.0.2 to RFIDIC 1.1.0.3 
##   
##   usage:
##      migrate_1.1.0.3.sh -components=DB,WAS -was_admin_user=was_admin -was_admin_password=was_password -was_runas_user=was_runas_user
##       e.g.
##               migrate_1.1.0.3.sh -components=DB,WAS 
##
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
. $SCRIPT_DIR/rfidic-env.sh


SIDDBSchema(){

if [ "$DB_TYPE" = "INFORMIX" ];then
	runUserCommand ${RFIDIC_USER} dbaccess -e - ${RFIDIC_HOME}/bin/Informix/ifx-serialid-schema.sql
fi
if [ "$DB_TYPE" = "ORACLE" ];then
	runUserCommand ${RFIDIC_USER} sqlplus "$DBMS_ADMN_USER"/"$DBMS_ADMN_PWD"@$DBMS_DB_NAME< $RFIDIC_HOME/bin/Oracle/ora-serialid-schema.sql
fi
if [ "$DB_TYPE" = "DB2" ];then
	runUserCommand ${RFIDIC_USER} db2 -tvf $RFIDIC_HOME/bin/DB2/db2_serialid_schema.sql
fi
}

databackup(){

stopWAS

	if [ "$DB_TYPE" = "INFORMIX" ];then
		DBDIR="Informix"
		runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/stopRFIDIC.sh -components=informix
		sleep 10
		runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/startRFIDIC.sh -components=informix
		sleep 20
		if [ -d "$RFIDIC_HOME/bin/RFIDIC_V"${prodVersion} ];then
		run_command rm -rf $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}
		fi
		run_command mkdir $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}
		run_command chown $RFIDIC_USER:$RFIDIC_GROUP $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}
		runUserCommand ${RFIDIC_USER} ${DBMS_HOME}/bin/dbexport ${DBMS_DB_NAME} -c -ss -X -o ${RFIDIC_HOME}/bin/RFIDIC_V${prodVersion}
	
	elif [ "$DB_TYPE" = "ORACLE" ];then
		DBDIR="Oracle"
		runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/stopRFIDIC.sh -components=oracle
		runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/startRFIDIC.sh -components=oracle
		if [ -d "$RFIDIC_HOME/bin/RFIDIC_V"${prodVersion} ];then
			run_command rm -rf $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}
		fi
		run_command mkdir $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}
		run_command chown $RFIDIC_USER:$RFIDIC_GROUP $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}
		run_command touch $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}/dbexport.out
		run_command chmod 577 $RFIDIC_HOME/bin/RFIDIC_V${prodVersion}/dbexport.out	
		runUserCommand ${RFIDIC_USER} ${DBMS_HOME}/bin/exp "$DBMS_ADMN_USER"/"$DBMS_ADMN_PWD"@$DBMS_DB_NAME file=${RFIDIC_HOME}/bin/RFIDIC_V${prodVersion}/dbexport.out full=yes
	
	elif [ "$DB_TYPE" = "DB2" ];then
		runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/stopRFIDIC.sh -components=db2
		runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/startRFIDIC.sh -components=db2
		runUserCommand ${RFIDIC_USER} ${DBMS_HOME}/bin/db2move rfidic export -u ${DBMS_ADMN_USER} -p ${DBMS_ADMN_PWD}
	fi
			
	if [ "$?" -eq 0 ]; then
		rfidic-get-message.sh RFID05120I
	else
		rfidic-get-message.sh RFID05121E
		exit 1
	fi
}

updateDBSchema(){

if [ "${prodVersion}" = "1.1.0.0" ];then

if [ ! "$DB_TYPE" = "INFORMIX" ];then
	echo "DB type not supported for this version of RFIDIC"
	echo "-------------------------------------------------"
	exit 1
fi
	echo "Updating 1.1.0.0 schema..."
	echo "-------------------------------------------------"
	if [ -f $RFIDIC_HOME/bin/Informix/tmp.txt ];then
		rm -f $RFIDIC_HOME/bin/Informix/tmp.txt
	fi
	if [ -f $RFIDIC_HOME/bin/Informix/tmp1.txt ];then
		rm -f $RFIDIC_HOME/bin/Informix/tmp1.txt
	fi

touch $RFIDIC_HOME/bin/Informix/export_policies.xml
touch $RFIDIC_HOME/bin/Informix/export_mdm.xml
touch $RFIDIC_HOME/bin/Informix/tmp.txt
touch $RFIDIC_HOME/bin/Informix/tmp1.txt

chmod 777 $RFIDIC_HOME/bin/Informix/export_policies.xml
chmod 777 $RFIDIC_HOME/bin/Informix/export_mdm.xml
chmod 777 $RFIDIC_HOME/bin/Informix/tmp.txt
chmod 777 $RFIDIC_HOME/bin/Informix/tmp1.txt

# Setting path of lib to old libraries.
b=":$RFIDIC_HOME/lib_bck/com.ibm.rfidic.mdm.export.v1_1.jar:$RFIDIC_HOME/lib_bck/EPCISBeans.jar"
for i in $RFIDIC_HOME/lib_bck/*.jar 
do
	c=$c:$i
done
c=$c:$TDI_HOME/jars/miconfig.jar:$TDI_HOME/jars/miserver.jar:$TDI_HOME/jars/jms.jar:$TDI_HOME/jars/miadmin.jar:$TDI_HOME/jars/connectors/FileSystems.jar:$MQ_HOME/java/lib/com.ibm.mqjms.jar:$MQ_HOME/java/lib/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar:$DBMS_HOME/jdbc/lib/ifxjdbcx.jar:$DBMS_HOME/jdbc/lib/ifxjdbc.jar
c=$b:$c
java -classpath $c -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.migrate.v1101.MigrateV1101 export $RFIDIC_HOME/bin/Informix/export_policies.xml
if [ "$?" -eq 0 ]; then
	rfidic-get-message.sh RFID05148W
else
	rfidic-get-message.sh RFID05149W
	exit 1
fi

echo "Exporting master data..."
java -classpath $c -DRFIDIC_HOME=$RFIDIC_HOME MdmExport $RFIDIC_HOME/bin/Informix/export_mdm.xml
if [ "$?" -eq 0 ]; then
	rfidic-get-message.sh RFID05152W
else
	rfidic-get-message.sh RFID05153W
	exit 1
fi

echo "Migrating tables..."
rfidic-get-message.sh RFID05140I
java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.migrate.v1101.MigrateV1101 tables

if [ "$?" -eq 0 ]; then
	rfidic-get-message.sh RFID05141I
else
	rfidic-get-message.sh RFID05142I
	exit 1
fi

java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.migrate.v1101.MigrateV1101 update $RFIDIC_HOME/bin/Informix/UpdateTables1101.sql
if [ "$?" -eq 0 ]; then
	rfidic-get-message.sh RFID05156W
else
	rfidic-get-message.sh RFID05157W
	exit 1
fi

#Create serial ID schema
echo "Creating Serial ID schema"
echo "-------------------------------------------------"
SIDDBSchema
if [ "$?" -eq 0 ]; then
	echo "Created serial id schema"
else
	echo "serial id schema creation not successful"
	exit 1
fi

echo "Migrating meta data..."
runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/deployMetadata.sh -migrate
if [ "$?" -eq 0 ]; then
	echo "Metadata migration was successful."
else
	echo "Metadata migration was not successful."
	exit 1
fi

sed s%location_id%external_id%g $RFIDIC_HOME/bin/Informix/export_policies.xml > $RFIDIC_HOME/bin/Informix/tmp1.txt
sed s%product_id%external_id%g $RFIDIC_HOME/bin/Informix/tmp1.txt > $RFIDIC_HOME/bin/Informix/tmp.txt
mv -f $RFIDIC_HOME/bin/Informix/tmp.txt $RFIDIC_HOME/bin/Informix/export_policies.xml

java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.migrate.v1101.MigrateV1101 import $RFIDIC_HOME/bin/Informix/export_policies.xml
if [ "$?" -eq 0 ]; then
	rfidic-get-message.sh RFID05150W
else
	rfidic-get-message.sh RFID05151W
	exit 1
fi

runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/import-masterdata.sh -load $RFIDIC_HOME/bin/Informix/export_mdm.xml
if [ "$?" -eq 0 ]; then
	echo "Successfully imported masterdata."
else
	echo "Masterdata import was not successful."
	exit 1
fi

java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.migrate.v1101.MigrateV1101 update $RFIDIC_HOME/bin/${DBDIR}/UpdateTables1103.sql
if [ "$?" -eq 0 ]; then
	echo "DB Schema migration to 1.1.0.3 successful."
else
	echo "DB Schema migration to 1.1.0.3 was not successful."
	exit 1
fi

echo "Migration to 1.1.0.3 completed."
exit 0
fi

if [ "${prodVersion}" = "1.1.0.1" ]
then

	for i in $RFIDIC_HOME/lib_bck/*.jar 
	do
		c=$c:$i
	done
	if [ "$DB_TYPE" = "ORACLE" ];then
		c=$c:$MQ_HOME/java/lib/com.ibm.mqjms.jar:$MQ_HOME/java/lib/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar:$DBMS_HOME/jdbc/lib/ojdbc14.jar
	elif [ "$DB_TYPE" = "INFORMIX" ];then
		c=$c:$MQ_HOME/java/lib/com.ibm.mqjms.jar:$MQ_HOME/java/lib/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar:$DBMS_HOME/jdbc/lib/ifxjdbcx.jar:$DBMS_HOME/jdbc/lib/ifxjdbc.jar
	fi

	java -classpath $c -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.migrate.v1101.MigrateV1101 update $RFIDIC_HOME/bin/${DBDIR}/UpdateTables1103.sql

	if [ "$?" -eq 0 ]; then
		echo "DB Schema migration to 1.1.0.3 successful."
	else
		echo "DB Schema migration to 1.1.0.3 was not successful."
		exit 1
	fi

	if [ "$DB_TYPE" = "ORACLE" ];then
		sqlplus "$DBMS_ADMN_USER"/"$DBMS_ADMN_PWD"@$DBMS_DB_NAME< $RFIDIC_HOME/bin/Oracle/update_fp2.sql
		if [ "$?" -eq 0 ]; then
			echo "Updated Oracle columns."
		else
			echo "Updating Oracle columns was not successful."
		fi
	fi

	#Create serial ID schema
	echo "Creating Serial ID schema"
	SIDDBSchema
	if [ "$?" -eq 0 ]; then
		echo "Created serial id schema"
	else
		errors=true
		echo "Serial id schema creation not successful"
	fi	
fi

if [ "${prodVersion}" = "1.1.0.2" ];then

	if [ "$DB_TYPE" = "ORACLE" ];then
		sqlplus "$DBMS_ADMN_USER"/"$DBMS_ADMN_PWD"@$DBMS_DB_NAME< $RFIDIC_HOME/bin/Oracle/update_fp2.sql
		if [ "$?" -eq 0 ]; then
			echo "Updated Oracle columns."
		else
			echo "Updating Oracle columns was not successful."
		fi
	fi

	#Create serial ID schema
	echo "Creating Serial ID schema"
	SIDDBSchema
	
	if [ "$?" -eq 0 ]; then
		echo "Created serial id schema"
	else
		echo "Serial id schema creation not successful"
		exit 1
	fi	
fi

# Perform data migration on boolean attributes
echo "Performing data migration..."
if [ "$DB_TYPE" = "ORACLE" -o "$DB_TYPE" = "DB2" ];then

for i in $RFIDIC_HOME/lib_bck/*.jar 
do
	c=$c:$i
done
if [ "$DB_TYPE" = "ORACLE" ];then
	c=$c:$MQ_HOME/java/lib/com.ibm.mqjms.jar:$MQ_HOME/java/lib/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar:$DBMS_HOME/jdbc/lib/ojdbc14.jar
elif [ "$DB_TYPE" = "DB2" ];then
	c=$c:$MQ_HOME/java/lib/com.ibm.mqjms.jar:$MQ_HOME/java/lib/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar:$DBMS_HOME/java/db2jcc.jar:$DBMS_HOME/java/db2jcc_javax.jar:$DBMS_HOME/java/db2jcc_license_cu.jar:$DBMS_HOME/java/db2jcc_license_cisuz.jar
fi

java -classpath $c -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.migrate.v1101.MigrateV1103
fi

echo "Migration to 1.1.0.3 completed."
runUserCommand ${was_runas_user} startServer.sh ${SERVERNAME}
}

reconfigWAS(){

if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
fi

if [ -n "$was_runas_user" ];then
	  was_runas="-was_runas_user=$was_runas_user"
fi

if [ -n "$was_runas_group" ];then
     	was_runas_group="-was_runas_group=$was_runas_group"
fi

if [ -n "$rfidic_user_password" ];then
	  rfidic_password="-rfidic_user_password=$rfidic_user_password"
fi

if [ -s "$WAS_HOME" ];then
	echo "Reconfiguring WAS..."
	run_command ${RFIDIC_HOME}/bin/rfidic-was-cfg.sh $credentials $was_runas $was_runas_group $rfidic_password -migrate=true
fi

}

stopWAS(){
   if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        stopServer.sh ${SERVERNAME} -username $was_admin_user -password $was_admin_password
   else
        stopServer.sh ${SERVERNAME}
   fi
}

usage(){

        rfidic-get-message.sh RFID05143I
	  exit
}

#### Input Arguments Verification #####

. $RFIDIC_HOME/bin/rfidic-env.sh
errors=false
components="DB WAS"

for item in $*
do
	if [ `expr match "$item" '-was_admin_user'` != 0 ];then
              was_admin_user=`echo ${item#-was_admin_user=}`
       elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
		      was_admin_password=`echo ${item#-was_admin_password=}`
	elif [ `expr match "$item" '-rfidic_user_password'` != 0 ];then
		    rfidic_user_password=`echo ${item#-rfidic_user_password=}`
	elif [ `expr match "$item" '-was_runas_group'` != 0 ];then
                  was_runas_group=`echo ${item#-was_runas_group=}`
	elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
                   was_runas_user=`echo ${item#-was_runas_user=}`
	elif [ `expr match "$item" '-components='` != 0 ];then
		components=`echo ${item#-components=}`
		components=`echo "$components" | tr "," "\n" | tr "[a-z]" "[A-Z]" | sort`
	else
            usage
      fi
done

if [ -z "$was_runas_user" ];then
	was_runas_user=${RFIDIC_USER}
fi

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
      rfidic-get-message.sh RFID05030I "$was_admin_user"
	stty -echo
	read was_admin_password
	stty echo
	echo
fi

umask 022

OS=`uname`
# read the RFIDIC product version
RFIDICBuildDate=`grep "Build Date:" $RFIDIC_HOME/VersionInfo/versionInfo.properties.bck | awk '{print($3)}'`
if [ "$OS" = "SunOS" ];then
	year=`echo $RFIDICBuildDate | awk -F/ '{print($3)}'`
	month=`echo $RFIDICBuildDate | awk -F/ '{print($1)}' | awk 'length()==1{print 0$0;next}{print $0}'`
	day=`echo $RFIDICBuildDate | awk -F/ '{print($2)}' | awk 'length()==1{print 0$0;next}{print $0}'`
else
	year=`echo $RFIDICBuildDate | awk -F "/" '{print($3)}'`
	month=`echo $RFIDICBuildDate | awk -F "/" '{print($1)}' | awk 'length()==1{print 0$0;next}{print $0}'`
	day=`echo $RFIDICBuildDate | awk -F "/" '{print($2)}' | awk 'length()==1{print 0$0;next}{print $0}'`
fi
date=$year$month$day
datecomp=`echo 20070718 $date | awk '$2<=$1{print -1;next}{print 1}'`
if [ "$datecomp" = 1 ];then
	datecomp2=`echo 20071107 $date | awk '$2<=$1{print -1;next}{print 1}'`
	if [ "$datecomp2" = 1 ];then
		prodVersion=1.1.0.2
	else
		prodVersion=1.1.0.1
	fi
else
	prodVersion=1.1.0.0
fi

for item in $components
do
case "$item" in
        DB)
		databackup
		updateDBSchema	
		;;
        WAS)
		reconfigWAS
		;;
esac
done

rfidic-get-message.sh RFID05112I
exit 0