#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: rfidic-was-cfg.sh	
##   Description: Configures WAS. Creates DataSource, scheduler and
##   		  installs an enterprise application
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
. $SCRIPT_DIR/rfidic-env.sh 

umask 022
connectDB(){
# Check Database status
java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect connect
db_status=$?
	if [ "$db_status" -ne 0 ];then
		#echo "Ensure that the database is running and then try again."
		rfidic-get-message.sh RFID05231E
		exit 1;
	fi
}

usage(){
	. $RFIDIC_HOME/bin/rfidic-env.sh > /dev/null
	 rfidic-get-message.sh RFID05086I "$0"
}

stopWAS(){
   if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        stopServer.sh ${SERVERNAME} -username $was_admin_user -password $was_admin_password
         credentials="-conntype SOAP -user $was_admin_user -password $was_admin_password"
   else
        stopServer.sh ${SERVERNAME}
   fi
}

updateBIRTDD(){
# Updating web.xml of UI Enterprise application
   CONTEXT_ROOT[0]=$WAS_HOME/profiles/$WAS_PROFILE/installedApps/$CELLNAME/com.ibm.rfidic.web.uiEAR.ear/com.ibm.rfidic.web.ui.reports.war
   CONTEXT_ROOT[1]=$WAS_HOME/profiles/$WAS_PROFILE/config/cells/$CELLNAME/applications/com.ibm.rfidic.web.uiEAR.ear/deployments/com.ibm.rfidic.web.uiEAR/com.ibm.rfidic.web.ui.reports.war
   count=${#CONTEXT_ROOT[*]}
   index=0
   while [ "$index" -lt "$count" ]
   do
        DD=${CONTEXT_ROOT[$index]}/WEB-INF/web.xml
   	if [ -f "$DD" ];then
        	BIRT_RESOURCE_PATH=${CONTEXT_ROOT}/Registry/Resources
	        line=`grep -n "<param-name>BIRT_RESOURCE_PATH</param-name>" $DD | sed 's,:.*,,'`
        	line=`expr $line + 1`
	        run_command sed -e "${line}s,.*,<param-value>${BIRT_RESOURCE_PATH}</param-value>," $DD > $DD.temp
        	run_command mv -f $DD.temp $DD
	       run_command rm -f $DD.temp
		run_command chown ${was_runas_user}:${was_runas_group} $DD
	fi
	index=`expr $index + 1`
   done
}

if [ $# -gt 6 ]
then
        usage
        exit 1
else
        for item in $*
        do
	   if [ `echo $item | wc -c` = 2 ];then
		usage
		exit 1
           elif [ `expr match "$item" '-clean'` != 0 ];then
			  CONFIG_OPTION=unconfigure
           elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
              was_admin_user=`echo ${item#-was_admin_user=}`
           elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
		      was_admin_password=`echo ${item#-was_admin_password=}`
           elif [ `expr match "$item" '-MQ_USER_PASSWORD'` != 0 ];then
		      MQ_USER_PASSWORD=`echo ${item#-MQ_USER_PASSWORD=}`
		elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
                   was_runas_user=`echo ${item#-was_runas_user=}`
		elif [ `expr match "$item" '-was_runas_group'` != 0 ];then
                   was_runas_group=`echo ${item#-was_runas_group=}`
		elif [ `expr match "$item" '-migrate'` != 0 ];then
                   migrate=`echo ${item#-migrate=}`
		   else
              usage
              exit 1
           fi
        done
fi


if [ -z "$CONFIG_OPTION" ]; then
	CONFIG_OPTION=configure
    rfidic-get-message.sh RFID05028I
    connectDB
else
	rfidic-get-message.sh RFID05069I
fi

getActualWASConfig

if [ -z "$was_runas_user" ];then
	was_runas_user=${RFIDIC_USER}
fi

if [ -z "$was_runas_group" ];then
	was_runas_group=${RFIDIC_GROUP}
fi

if [ -z "$migrate" ];then
	migrate=false
fi

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
      rfidic-get-message.sh RFID05030I "$was_admin_user"
	stty -echo
	read was_admin_password
	stty echo
	echo
fi

# Note: if WAS wasn't started there will be an error here we can ignore it
stopWAS
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 246 ];then
	echo "The stopWAS command returned a non-zero code"
	exit $retCode
fi

startServer.sh ${SERVERNAME}
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 127 ];then
	echo "The startServer.sh command returned a non-zero code"
	exit $retCode
fi

if [ "$migrate" = "false" ];then

mq_install_root=${MQ_INSTALL_PATH}
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/resetVariables.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $RFIDIC_HOME $DB_TYPE $DBMS_HOME_LIB $mq_install_root $was_runas_user $was_runas_group
if [ "$DB_TYPE" = "INFORMIX" ]
then
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $SERVERNAME $DBMS_ALIAS $DBMS_ADMN_USER $DBMS_ADMN_PWD "RFIDIC Informix JDBC Provider" "Provider for RFIDIC data" "Ifx Data Source" "Ifx database settings" $DBMS_DB_NAME $DBMS_SERVER $IFX_PORT_NUMBER $DB_HOST jdbc/rfidic/ifx $DB_LOCALE $CLIENT_LOCALE "false" $DB_TYPE
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $SERVERNAME $DBMS_ALIAS $DBMS_ADMN_USER $DBMS_ADMN_PWD "RFIDIC Informix JDBC XA Provider" "Provider for RFIDIC data" "rfidicXA" "Ifx database settings" $DBMS_DB_NAME $DBMS_SERVER $IFX_PORT_NUMBER $DB_HOST jdbc/rfidic/ifxXA $DB_LOCALE $CLIENT_LOCALE "true" $DB_TYPE

# Configure default published message serializer
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $DBMS_ALIAS "RFIDIC Informix JDBC Provider" "Ifx Publisher Data Source" "Local datasource configuration" $DBMS_DB_NAME $DBMS_SERVER $IFX_PORT_NUMBER $DB_HOST jdbc/rfidic/pub/default $DB_LOCALE $CLIENT_LOCALE "false" $DB_TYPE

fi

if [ "$DB_TYPE" = "ORACLE" ]
then
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $SERVERNAME $DBMS_ALIAS $DBMS_ADMN_USER $DBMS_ADMN_PWD "RFIDIC Oracle JDBC Provider" "Provider for RFIDIC data" "Oracle Data Source" "Oracle database settings" $DBMS_DB_NAME " " $ORACLE_PORT_NUMBER $DB_HOST jdbc/rfidic/ifx " " " " "false" $DB_TYPE $ORACLE_JDBC_URL
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $SERVERNAME $DBMS_ALIAS $DBMS_ADMN_USER $DBMS_ADMN_PWD "RFIDIC Oracle JDBC XA Provider" "Provider for RFIDIC data" "rfidicXA" "Oracle database settings" $DBMS_DB_NAME " " $ORACLE_PORT_NUMBER $DB_HOST jdbc/rfidic/ifxXA " " " " "true" $DB_TYPE $ORACLE_JDBC_URL

	# Configure default published message serializer
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $DBMS_ALIAS "RFIDIC Oracle JDBC Provider" "Oracle Publisher Data Source" "Local datasource configuration" $DBMS_DB_NAME " " $ORACLE_PORT_NUMBER $DB_HOST jdbc/rfidic/pub/default " " " " "false" $DB_TYPE $ORACLE_JDBC_URL

fi

if [ "$DB_TYPE" = "DB2" ]
then
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $SERVERNAME $DBMS_ALIAS $DBMS_ADMN_USER $DBMS_ADMN_PWD "RFIDIC DB2 JDBC Provider" "Provider for RFIDIC data" "DB2 Data Source" "DB2 database settings" $DBMS_DB_NAME $DB2_SERVER $DB2_PORT_NUMBER $DB_HOST jdbc/rfidic/ifx " " " " "false" $DB_TYPE " "
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $SERVERNAME $DBMS_ALIAS $DBMS_ADMN_USER $DBMS_ADMN_PWD "RFIDIC DB2 JDBC XA Provider" "Provider for RFIDIC data" "rfidicXA" "DB2 database settings" $DBMS_DB_NAME $DB2_SERVER $DB2_PORT_NUMBER $DB_HOST jdbc/rfidic/ifxXA " " " " "true" $DB_TYPE " "

	# Configure default published message serializer
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION $DBMS_ALIAS "RFIDIC DB2 JDBC Provider" "DB2 Publisher Data Source" "Local datasource configuration" $DBMS_DB_NAME $DB2_SERVER $DB2_PORT_NUMBER $DB_HOST jdbc/rfidic/pub/default " " " " "false" $DB_TYPE

fi
fi

QCFName="rfidicConnFac"
QCFDesc="RFIDIC XA QueueConnectionFactory" 
QCFjndi="jms/rfidicQConnFac"
MQHost=$MQ_HOST
MQPort=$MQ_LSR_PORT
MQAlias="RFIDICMQAlias"

run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateMQQCF.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QCFName" "$QCFDesc" $QCFjndi $MQHost $MQPort $QUEUE_MANAGER $MQAlias "true" $MQ_USER $MQ_USER_PASSWORD

QCFName="rfidicQCF"
QCFDesc="RFIDIC Queue Connection Factory" 
QCFjndi="jms/rfidicQCF"
MQHost=$MQ_HOST
MQPort=$MQ_LSR_PORT
MQAlias="RFIDICMQAlias"

run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateMQQCF.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QCFName" "$QCFDesc" $QCFjndi $MQHost $MQPort $QUEUE_MANAGER $MQAlias "true" $MQ_USER $MQ_USER_PASSWORD


QName="rfidicMQDest"
QDesc="Queue for RFIDIC"
Qjndi="jms/rfidicMQDest"

run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateMQQ.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $QUEUE_NAME $QUEUE_MANAGER


QName="rfidicAlertsInputMQDest"
QDesc="Input Queue for RFIDIC Alerts processing engine"
Qjndi="jms/rfidicAlertsInputMQDest"

run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateMQQ.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $ALERTS_ENGINE_INPUT_QUEUE_NAME $QUEUE_MANAGER

#QName="rfidicMDMChangeNotif"
#QDesc="Output Queue for RFIDIC MDM Change Notifications"
#Qjndi="jms/ibm/rfidic/mdm/changeNotification"

#run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateMQQ.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $MDM_CHANGE_NOTIF_QUEUE_NAME $QUEUE_MANAGER

TCFName="RFIDICMQTCF"
TCFJndi="jms/ibm/epcis/TCF"
TCFDesc="Topic connection factory for MDM change notification"
TopicName="RFIDICMQAdminTopic"
TopicJNDI=jms/ibm/epcis/mdm/changeNotification
MQHost=$MQ_HOST
MQPort=$MQ_LSR_PORT
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/createTopicConfig.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $MQHost $MQPort $QUEUE_MANAGER $TopicJNDI $TopicName $TCFJndi $TCFName $TCFDesc


LPjndi="jms/rfidicMQDest"
LPName="rfidicMQListener"
QCF="jms/rfidicQConnFac"
State="STOP"
  
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateListener.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $LPjndi $LPName $QCF $State


LPjndi="jms/rfidicAlertsInputMQDest"
LPName="rfidicAlertsMQListener"
QCF="jms/rfidicQCF"
State="START"

run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateListener.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $LPjndi $LPName $QCF $State

if [ "$CONFIG_OPTION" = configure ]; then
	cd $RFIDIC_HOME/bin	
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
		run_command $RFIDIC_HOME/bin/recreateAS2MQ.sh -was_admin_user=$was_admin_user -was_admin_password=$was_admin_password -MQ_USER_PASSWORD=$MQ_USER_PASSWORD
	else
        run_command $RFIDIC_HOME/bin/recreateAS2MQ.sh -MQ_USER_PASSWORD=$MQ_USER_PASSWORD
	fi		
else
	run_command $RFIDIC_HOME/bin/recreateAS2MQ.sh -clean
fi


# create the shared library that contains the RFIDIC jars and a server class loader that uses it
RFIDIC_JARS_PATH_PREFIX="${RFIDIC_HOME}/lib/"
RFIDIC_JARS=`cd $RFIDIC_HOME/lib;ls *.jar`
for jar in $RFIDIC_JARS
do
  RFIDIC_JARS_PATH=$RFIDIC_JARS_PATH$RFIDIC_JARS_PATH_PREFIX$jar:
done
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_HOME/bin/jacl/setLibrary.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME RFIDIC_UI_LIB $RFIDIC_JARS_PATH "Shared libraries for RFIDIC UI applications."

stopWAS
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 246 ];then
	echo "The stopWAS command returned a non-zero code"
	exit $retCode
fi
run_command chgrp ${was_runas_group} ${WAS_HOME}/..
run_command chgrp ${was_runas_group} ${WAS_HOME}
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/profiles
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/profiles/${WAS_PROFILE}
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/logs
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/properties
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/temp
# Varies on the WAS version and edition
if [ -d "${WAS_HOME}/cloudscape" ];then
	chgrp -R ${was_runas_group} ${WAS_HOME}/cloudscape
	chmod -R g+wr ${WAS_HOME}/cloudscape
fi
if [ -d "${WAS_HOME}/derby" ];then
	chgrp -R ${was_runas_group} ${WAS_HOME}/derby
	chmod -R g+wr ${WAS_HOME}/derby
fi
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/bin
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/java
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/lib
# Varies on the WAS version and edition
if [ -d "${WAS_HOME}/installedChannels" ];then
	chgrp -R ${was_runas_group} ${WAS_HOME}/installedChannels
	chmod -R g+rw ${WAS_HOME}/installedChannels
fi
if [ -d "${WAS_HOME}/installedConnectors" ];then
	chgrp -R ${was_runas_group} ${WAS_HOME}/installedConnectors
	chmod -R g+rw ${WAS_HOME}/installedConnectors
fi
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/profiles/${WAS_PROFILE}/installedFilters
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/etc/
# Varies on the WAS version and edition
if [ -d ${WAS_HOME}/classes ];then
	chgrp -R ${was_runas_group} ${WAS_HOME}/classes
	chmod -R g+rw ${WAS_HOME}/classes
fi
run_command chgrp -R ${was_runas_group} ${WAS_HOME}/systemApps

run_command chmod g+wr ${WAS_HOME}/..
run_command chmod g+wr ${WAS_HOME}
run_command chmod -R g+wr ${WAS_HOME}/profiles
run_command chmod -R g+rw ${WAS_HOME}/profiles/${WAS_PROFILE}
run_command chmod -R g+wr ${WAS_HOME}/logs
run_command chmod -R g+wr ${WAS_HOME}/properties
run_command chmod -R g+wr ${WAS_HOME}/temp
run_command chmod -R g+r ${WAS_HOME}/bin
run_command chmod -R g+r ${WAS_HOME}/java
run_command chmod -R g+r ${WAS_HOME}/lib
run_command chmod -R g+rw ${WAS_HOME}/profiles/${WAS_PROFILE}/installedFilters
run_command chmod -R g+rw ${WAS_HOME}/etc/
run_command chmod -R g+rw ${WAS_HOME}/systemApps

runUserCommand ${was_runas_user} $WAS_HOME/bin/startServer.sh ${SERVERNAME}
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 127 ];then
	echo "The startServer.sh command returned a non-zero code"
	exit $retCode
fi

if [ "$migrate" = "false" ];then
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateScheduler.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME RFIDICStandingQueryScheduler jdbc/rfidic/ifx $DBMS_ALIAS 10 RFIDIC_ RFIDICWorkManager wm/rfidic/standing
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/createSchedTables.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME RFIDICStandingQueryScheduler
fi
#Create Serial ID Scheduler Table
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateScheduler.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME SerialIdScheduler jdbc/rfidic/ifx $DBMS_ALIAS 60 SERIALID_ SerialIdWorkManager wm/Serialid
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/createSchedTables.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME SerialIdScheduler


START_OPTION=no_start
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $RFAPP_LOCATION $RFAPP_NAME $START_OPTION
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $UIAPP_LOCATION $UIAPP_NAME $START_OPTION

#### Serial ID Application #########
run_command ejbdeploy.sh $SIDAPP_LOCATION /tmp /tmp/com.ibm.rfidic.web.enterprise.serialid.deployed.ear
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME /tmp/com.ibm.rfidic.web.enterprise.serialid.deployed.ear $SIDAPP_NAME $START_OPTION

if [ "$CONFIG_OPTION" = "configure" ]
then
	updateBIRTDD
fi

run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $RFIDIC_ALERTS_APP_LOCATION $RFIDIC_ALERTS_APP_NAME $START_OPTION


run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateAuditConfig.jacl "unconfigure" $CELLNAME $NODENAME $SERVERNAME $HOSTNAME $RFIDIC_BUS_NAME
run_command rm -rf $WAS_HOME/profiles/default/databases/com.ibm.ws.sib/$NODENAME.$SERVERNAME-$RFIDIC_BUS_NAME
stopWAS
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 246 ];then
	echo "The stopWAS command returned a non-zero code"
	exit $retCode
fi

runUserCommand ${was_runas_user} $WAS_HOME/bin/startServer.sh ${SERVERNAME}
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 127 ];then
	echo "The startServer.sh command returned a non-zero code"
	exit $retCode
fi
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateAuditConfig.jacl $CONFIG_OPTION $CELLNAME $NODENAME $SERVERNAME $HOSTNAME $RFIDIC_BUS_NAME


#### Configuration of the default message serializer for published messages #########
run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $RFIDIC_PUB_MSGSER_APP_LOC $RFIDIC_PUB_MSGSER_APP_NAME $START_OPTION

stopWAS
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 246 ];then
	echo "The stopWAS command returned a non-zero code"
	exit $retCode
fi

runUserCommand ${was_runas_user} $WAS_HOME/bin/startServer.sh ${SERVERNAME}
retCode=$?
if [ "$retCode" != 0 -a "$retCode" != 127 ];then
	echo "The startServer.sh command returned a non-zero code"
	exit $retCode
fi

exit 0
