#! /bin/sh 
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: rfidicIVT.sh	
##   Description: Script to verify if all the installation is done correctly
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . ${RFIDIC_HOME}/bin/rfidic-env.sh
else
        . ${SCRIPT_DIR}/rfidic-env.sh
fi

usage(){
	 rfidic-get-message.sh RFID05242I "$0"
}


for item in $*
do
	if [ `expr match "$item" '-was_admin_user'` != 0 ];then
      		was_admin_user=`echo ${item#-was_admin_user=}`
	elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
      		was_admin_password=`echo ${item#-was_admin_password=}`
	elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
      		was_runas_user=`echo ${item#-was_runas_user=}`
	else
		usage			
		exit 1
	fi
done

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
       rfidic-get-message.sh -noid RFID05057I "$was_admin_user: "
	stty -echo
	read was_admin_password
	stty echo
fi
if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
	credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
fi
if [ -n "$was_runas_user" ];then
	was_runas="-was_runas_user=$was_runas_user"
fi
echo '*************************************************************************'
echo 'RFIDIC IVT (Install Verification Tool) will now verify the installation...'
echo 'Please make sure this is run only on a fresh installation and NOT for upgradation.'
echo 'There are 5 steps to verification. If any one of them fails, the IVT will exit with the appropriate error message...'
echo 'Step 1 of 5 - Deploy Sample MetaData.'
echo '*************************************************************************'
sleep 3
run_command ${RFIDIC_HOME}/bin/deployMetadata.sh -force_drop_tables -force_stop_was $credentials
if [ $? -eq 0 ]; then
	echo '*************************************************************************'
	echo 'Deploy Sample Metadata successful'
else
	echo '*************************************************************************'
	echo 'Deploy Sample Metadata FAILED'
        exit 1
fi
${RFIDIC_HOME}/bin/startRFIDIC.sh $was_runas
echo 'Step 2 of 5 - Import Sample Master Data.'
echo '*************************************************************************'
sleep 3
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/Category.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (Category.xml) FAILED'
	exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/Product.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (Product.xml) FAILED'
	exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/ProductHierarchy.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (ProductHierarchy.xml) FAILED'
	exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/ProductSet.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (ProductSet.xml) FAILED'
	exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/Location.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (Location.xml) FAILED'
	exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/LocationHierarchy.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (LocationHierarchy.xml) FAILED'
	exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/actionValues.xml
if [ $? -ne 0 ]; then
        echo '*************************************************************************'
        echo 'Import of MasterData (actionValues.xml) FAILED'
        exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/coreBusinessVocabularyDraft.xml
if [ $? -ne 0 ]; then
        echo '*************************************************************************'
        echo 'Import of MasterData (coreBusinessVocabularyDraft.xml) FAILED'
        exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/LocationSet.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (LocationSet.xml) FAILED'
	exit 1
fi
run_command ${RFIDIC_HOME}/bin/import-masterdata.sh ${RFIDIC_HOME}/samples/mdm/Vocabulary.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Import of MasterData (Vocabulary.xml) FAILED'
	exit 1
else
	echo '*************************************************************************'
	echo 'Import of MasterData was Successful'
fi
echo '*************************************************************************'
echo 'Verifying the import of Master Data'
echo '*************************************************************************'
sleep 3
echo '*************************************************************************'
run_command ${RFIDIC_HOME}/bin/verifyImportMasterData.sh
if [ $? -eq 0 ]; then
	echo '*************************************************************************'
	echo 'Import of Sample Master Data successful'
else
	echo '*************************************************************************'
	echo 'Import of Sample Master Data FAILED'
	exit 1
fi
echo 'Step 3 of 5 - Capturing Event Data. This verifies the MQ connectivity.'
echo '*************************************************************************'
sleep 3
run_command ${RFIDIC_HOME}/bin/submitEvent.sh myeventq $RFIDIC_HOME/samples/EPCISSpecificationEPCISDocument.xml 
if [ $? -eq 0 ]; then
	echo '*************************************************************************'
	echo 'Capture Event Data successful'
else
	echo '*************************************************************************'
	echo 'Capture Event Data FAILED '
	exit 1
fi
echo 'Step 4 of 5 - Query Event Data. This will verify the MQ-WAS-DB connectivity.'
echo '*************************************************************************'
sleep 20
determineIP
echo $IP
echo $WAS_PORT_NO
run_command rm -rf /tmp/QueryOutput.xml 1>&2 > /dev/null
run_command ${RFIDIC_HOME}/bin/simpleEventQuery.sh -url_prefix http://$IP:$WAS_PORT_NO 1>&2 > /tmp/QueryOutput.xml
if [ $? -ne 0 ]; then
	echo '*************************************************************************'
	echo 'Query of Event Data FAILED '
	sleep 2;
	exit 1;
fi
/bin/grep -i "<epc>" /tmp/QueryOutput.xml 1>&2  > /dev/null
returncode=$?
if [ $returncode -ne 0 ] 
then
	echo  "*************************************************************************"
	echo  "Query of Event Data FAILED "
	sync;
	exit 1
else
	echo '*************************************************************************'
	echo 'Query of Event Data was Successful'
fi
echo 'Step 5 of 5 - Verify SID (Serial ID) Generation. This verifies the SID Module'
echo '*************************************************************************'
sleep 3
run_command ${RFIDIC_HOME}/bin/verifySID.sh $IP $WAS_PORT_NO
if [ $? -eq 0 ]; then
	echo '*************************************************************************'
	echo 'SID Verification Successful.'
else 
	echo '*************************************************************************'
	echo 'SID Verification FAILED.'
	exit 1;
fi
echo 'Cleaning up sample master data and event data.'
echo '*************************************************************************'
sleep 3
run_command ${RFIDIC_HOME}/bin/deployMetadata.sh -force_drop_tables -force_stop_was $credentials
${RFIDIC_HOME}/bin/startRFIDIC.sh $was_runas
echo '*************************************************************************'
echo 'All verifications went through fine.'
echo 'You can now start using the server. Please restart before using.'
echo '*************************************************************************'
exit 0
