#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: startRFIDIC.sh
##   Description: Script to start all the prerequisite software of RFIDIC,
##   namely, Informix, MQ, CAPTURE and WAS.
##
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . $RFIDIC_HOME/bin/rfidic-env.sh
else
        . $SCRIPT_DIR/rfidic-env.sh
fi

usage(){
	rfidic-get-message.sh RFID05083I "$0"
}

startMQ(){
	distributed $MQ_HOST
	mq_dist=$?
	
   echo "========================================="

if [ "$mq_dist" = "1" ];then
	echo "Ensure that WebSphere MQ queue manager is running on the host $MQ_HOST"
	return
fi
   if [ -d "$MQ_HOME" ]
    then
        rfidic-get-message.sh RFID05038I
        strmqm ${QUEUE_MANAGER}
        
        runmqlsr -t tcp -m ${QUEUE_MANAGER} -p ${MQ_LSR_PORT} &                
else
  rfidic-get-message.sh RFID05039E "$MQ_HOME"
fi

sleep 5
strmqbrk -m ${QUEUE_MANAGER}

return
}

startInformix(){
distributed $DB_HOST
db_dist=$?
	
   echo "========================================="

if [ "$db_dist" = "1" ];then
	java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect connect
	db_status=$?
	if [ "$db_status" -ne 0 ];then
		echo "Ensure that the Informix database on host $DB_HOST is running."
		return
	fi

	echo "The Informix database on host $DB_HOST is running."
	return
fi   
if [ -d "$DBMS_HOME" ]
then
     rfidic-get-message.sh RFID05040I
	 oninit -y
     onstat -
else
     rfidic-get-message.sh RFID05041E "$DBMS_HOME"
     exit -1
fi
return
}

startOracle(){
distributed $DB_HOST
db_dist=$?
	
   echo "========================================="

if [ "$db_dist" = "1" ];then
	java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect connect
	db_status=$?
	if [ "$db_status" -ne 0 ];then
		echo "Ensure that the Oracle database on host $DB_HOST is running."
		return
	fi

	echo "The Oracle database on host $DB_HOST is running."
	return
fi   

   if [ -d "$DBMS_HOME" ]
   then
     #echo "Starting Oracle..." 
     rfidic-get-message.sh RFID05227I
	if [ "$OS" = "SunOS" ];then
		db_start=`grep rfidic /var/opt/oracle/oratab | awk -F: '{print($3)}'`
	else
     		db_start=`grep rfidic /etc/oratab | awk -F ":" '{print($3)}'`
	fi
     if [ "$db_start" = "N" ]
     then
		if [ "$OS" = "SunOS" ];then
			sed -e "s,rfidic:$DBMS_HOME:N,rfidic:$DBMS_HOME:Y," /var/opt/oracle/oratab > /var/opt/oracle/oratab.temp
			mv -f /var/opt/oracle/oratab.temp /var/opt/oracle/oratab
			chmod 666 /var/opt/oracle/oratab
		else
			sed -e 's "rfidic:$DBMS_HOME:N" "rfidic:$DBMS_HOME:Y" g\n' /etc/oratab > /etc/oratab
		fi
     fi 

     $DBMS_HOME/bin/dbstart
else
     #echo "Starting Oracle failed because RBDMS was not found in $DBMS_HOME" 
     rfidic-get-message.sh RFID05226E "$DBMS_HOME"
     exit -1
fi
return
}

startDB2(){
distributed $DB_HOST
db_dist=$?
	
   echo "========================================="

if [ "$db_dist" = "1" ];then
	java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect connect
	db_status=$?
	if [ "$db_status" -ne 0 ];then
		echo "Ensure that the DB2 database on host $DB_HOST is running."
		return
	fi

	echo "The DB2 database on host $DB_HOST is running."
	return
fi   

   if [ -d "$DBMS_HOME" ]
   then
     	#echo "Starting DB2..." 
     	rfidic-get-message.sh RFID05234I
      /home/$DB2_INSTANCE/sqllib/adm/db2start
   else
     	#echo "Starting Oracle failed because RBDMS was not found in $DBMS_HOME" 
     	rfidic-get-message.sh RFID05226E "$DBMS_HOME"
     	exit -1
   fi
return
}

startCAPTURE(){
   echo "========================================="
 	getActualWASConfig

        # if was_admin_user is given and password is empty then read the password
	if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
	      rfidic-get-message.sh RFID05030I "$was_admin_user"
		stty -echo
		read was_admin_password
		stty echo
	fi
	
	#Start the listener 
	rfidic-get-message.sh RFID05088I
	
	credentials="-conntype SOAP -user $was_admin_user -password $was_admin_password"
	
	#If was_admin_user is empty then start the listener with out credentials
	if [ -z "$was_admin_user" ]; then
		credentials=""
	fi
	
	wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/startMQListener.jacl $CELLNAME $NODENAME $SERVERNAME start
	
		if [ "$?" -eq "0" ]; then
			rfidic-get-message.sh RFID05089I
		else
			rfidic-get-message.sh RFID05113I
		fi
return
}

startWAS(){
echo "========================================="
# Check was_runas_user
if [ "$was_runas_user" = "$RFIDIC_USER" ];then
	unset was_runas_user
fi
if [ -d "$WAS_HOME" ]
then
        rfidic-get-message.sh RFID05046I
	if [ -z "$was_runas_user" ];then
	        startServer.sh $SERVERNAME
	else
		runUserCommand ${was_runas_user} $WAS_HOME/bin/startServer.sh ${SERVERNAME} 
	fi
else
        rfidic-get-message.sh RFID05048I "$WAS_HOME"
fi
return
}

startIEHS(){
	echo "============================================"
if [ -d "$RFIDIC_HOME/ibm_help" ]
then
	cd ${RFIDIC_HOME}/ibm_help
	rfidic-get-message.sh RFID05241I
	$RFIDIC_HOME/ibm_help/IC_start.sh &
	sleep 10
else
        rfidic-get-message.sh RFID05244E "$RFIDIC_HOME/ibm_help"
fi
cd $SCRIPT_DIR
}

# main processing
components="$DB_TYPE MQ WAS CAPTURE IEHS"
	

for item in $@
        do
		if [ `echo $item | wc -c` = 2 ];then
			usage
			exit -1
                elif [ `expr match "$item" '-components='` != 0 ];then
                        components=`echo ${item#-components=}`
                        components=`echo "$components" |tr "[a-z]" "[A-Z]"`
                        components=`echo "$components" | sed "s/CAPTURE/WASCAPTURE/g"`

#Making input case neutral and ensuring the components are started in the right order

                        components=`echo "$components" | tr "," "\n" | sort`
                        components=`echo "$components" | sed "s/WASCAPTURE/CAPTURE/g"`

			shift
                elif [ `expr match "$item" '-was_runas_user='` != 0 ];then
                        was_runas_user=`echo ${item#-was_runas_user=}`
			shift
                elif [ `expr match "$item" '-was_admin_user='` != 0 ];then
                        was_admin_user=`echo ${item#-was_admin_user=}`
                        shift
                elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
                        was_admin_password=`echo ${item#-was_admin_password=}`
                        shift			
                else
                        usage
                        exit -1
                fi
done

. $RFIDIC_INSTALL_HOME/bin/rfidic-env.sh  > /dev/null
comp=`echo $components|sed "s/ /|/g"`
rfidic-get-message.sh RFID05036I "$comp"
for item in $components
do
  case "$item" in
	INFORMIX)
		startInformix
		;;
	ORACLE)
		startOracle
                ;;
	DB2)
		startDB2
		;;
        MQ)
                startMQ
                ;;
        WAS)
                startWAS
                ;;
        	
        CAPTURE)
		startCAPTURE
                ;;
	 IEHS)
	      startIEHS
		  ;;
        *)
                  rfidic-get-message.sh RFID05037I $item
  esac
done
