#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: stopRFIDIC.sh	
##   Description: Script to stop all the prerequisite software of RFIDIC,
##   namely, Informix, MQ, TDI and WAS.
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . $RFIDIC_HOME/bin/rfidic-env.sh
else
        . $SCRIPT_DIR/rfidic-env.sh
fi

usage(){
	 rfidic-get-message.sh RFID05084I "$0"
}


stopMQ(){
endmqbrk -m ${QUEUE_MANAGER}
distributed $MQ_HOST
mq_dist=$?
	
echo "========================================="

if [ "$mq_dist" = "1" ];then
	echo "Ensure that WebSphere MQ queue manager is stopped on the host $MQ_HOST"
	return
fi
if [ -d "$MQ_HOME" ]
then

	rfidic-get-message.sh RFID05051I  
	endmqlsr -m ${QUEUE_MANAGER}
	endmqm -w ${QUEUE_MANAGER}
else
	rfidic-get-message.sh RFID05052E "$MQ_HOME"
fi
return
}

stopInformix(){
distributed $DB_HOST
db_dist=$?
	
echo "========================================="

if [ "$db_dist" = "1" ];then
	echo "Ensure that the Informix server instance is stopped on the host $DB_HOST"
	return
fi
if [ -d "$DBMS_HOME" ]
then
	rfidic-get-message.sh RFID05053I 
	onmode -ky
else
	rfidic-get-message.sh RFID05054E "$DBMS_HOME" 
	exit -1
fi
return
}

stopOracle(){
distributed $DB_HOST
db_dist=$?
	
echo "========================================="

if [ "$db_dist" = "1" ];then
	echo "Ensure that the Oracle server instance is stopped on the host $DB_HOST"
	return
fi
if [ -d "$DBMS_HOME" ]
then
	#echo "Stopping Oracle..."
	rfidic-get-message.sh RFID05228I
	if [ "$stop_db" != "true" ];then
			promptUserDBStop
	fi
	if [ "$OS" = "SunOS" ];then
		db_stop=`grep $DBMS_DB_NAME /var/opt/oracle/oratab | awk -F: '{print($3)}'`
	else
     		db_stop=`grep $DBMS_DB_NAME /etc/oratab | awk -F ":" '{print($3)}'`
	fi
	if [ "$stop_db" = "true" ];then
	      	if [ "$db_stop" = "N" ]
      		then
			if [ "$OS" = "SunOS" ];then
				sed -e "s,$DBMS_DB_NAME:$DBMS_HOME:N,$DBMS_DB_NAME:$DBMS_HOME:Y," /var/opt/oracle/oratab > /var/opt/oracle/oratab.temp
				mv -f /var/opt/oracle/oratab.temp /var/opt/oracle/oratab
				chmod 666 /var/opt/oracle/oratab
			else
				sed -e 's "$DBMS_DB_NAME:$DBMS_HOME:N" "$DBMS_DB_NAME:$DBMS_HOME:Y" g\n' /etc/oratab > /etc/oratab
			fi
      		fi 
      		$DBMS_HOME/bin/dbshut
	fi
else
	#echo "Oracle could not be stopped as the RDBMS was not found under, $DBMS_HOME"
	rfidic-get-message.sh RFID05229E "$DBMS_HOME"
	exit -1
fi
return
}

stopDB2(){
distributed $DB_HOST
db_dist=$?
	
echo "========================================="

if [ "$db_dist" = "1" ];then
	echo "Ensure that the DB2 server instance is stopped on the host $DB_HOST"
	return
fi

if [ -d "$DBMS_HOME" ]
then
	#echo "Stopping DB2..."
	#echo "Stopping DB2..."
	rfidic-get-message.sh RFID05233I 
	if [ "$stop_db" != "true" ];then
			promptUserDBStop
	fi

	if [ "$stop_db" = "true" ]
	then
		/home/$DB2_INSTANCE/sqllib/adm/db2stop force
	else
		/home/$DB2_INSTANCE/sqllib/adm/db2stop
	fi

	
else
	rfidic-get-message.sh RFID05054E "$DBMS_HOME" 
	exit -1
fi
return
}


stopCapture(){
	echo "========================================="
	

	getActualWASConfig
	

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
      rfidic-get-message.sh RFID05030I "$was_admin_user"
	stty -echo
	read was_admin_password
	stty echo
fi

#Start the listener 
rfidic-get-message.sh RFID05096I

credentials="-conntype SOAP -user $was_admin_user -password $was_admin_password"

#If was_admin_user is empty then start the listener with out credentials
if [ -z "$was_admin_user" ]; then
	credentials=""
fi

wsadmin.sh -wsadmin_classpath $CLASSPATH $credentials -f $RFIDIC_INSTALL_HOME/bin/jacl/startMQListener.jacl $CELLNAME $NODENAME $SERVERNAME stop

if [ "$?" -eq "0" ]; then
	rfidic-get-message.sh RFID05097I
else
	rfidic-get-message.sh RFID05114I
fi
 

return

}

stopWAS(){
	echo "========================================="
if [ -d "$WAS_HOME" ]
then
	rfidic-get-message.sh RFID05056I    
	if [ -n "$was_admin_user" ];then
		if [ -z "$was_admin_password" ];then
			rfidic-get-message.sh -noid RFID05057I "$was_admin_user: "
			stty -echo
			read was_admin_password
			stty echo
		fi
		stopServer.sh $SERVERNAME -username $was_admin_user -password $was_admin_password
	else
		stopServer.sh $SERVERNAME
	fi
else
	rfidic-get-message.sh RFID05058E "$WAS_HOME"
fi
return
}

stopIEHS(){
	echo "==========================================="
if [ -d "$RFIDIC_HOME/ibm_help" ]
then
	cd ${RFIDIC_HOME}/ibm_help
	rfidic-get-message.sh RFID05240I
	$RFIDIC_HOME/ibm_help/IC_end.sh
else
        rfidic-get-message.sh RFID05243E "$RFIDIC_HOME/ibm_help"
fi
cd $SCRIPT_DIR
}


components="CAPTURE WAS MQ $DB_TYPE IEHS"
	

if [ $# -gt 3 ]
then
        usage
        exit -1
else
        for item in $*
        do
		if [ `echo $item | wc -c` = 2 ];then
			usage
			exit -1
                elif [ `expr match "$item" '-components='` != 0 ];then
                        components=`echo ${item#-components=}`
                        components=`echo "$components" |tr "[a-z]" "[A-Z]"`
			components=`echo "$components" | sed "s/CAPTURE/WASCAPTURE/g"`

#Making input case neutral and ensuring the components are started in the right order
                        components=`echo "$components" | tr "," "\n" | sort -r`
			components=`echo "$components" | sed "s/WASCAPTURE/CAPTURE/g"`

		elif [ `expr match "$item" '-was_admin_user='` != 0 ];then
			was_admin_user=`echo ${item#-was_admin_user=}`
		elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
			was_admin_password=`echo ${item#-was_admin_password=}`
                else
                        usage
                        exit -1
                fi
        done
fi


comp=`echo $components|sed "s/ /|/g"`
rfidic-get-message.sh RFID05049I "$comp" 

for item in $components
do
  case "$item" in
        INFORMIX)
		stopInformix
		;;
	ORACLE)
		stopOracle
		;;
	DB2)
		stopDB2
		;;
	CAPTURE)
		stopCapture
		;;
		
        MQ)
		stopMQ
		;;
        WAS)
		stopWAS
		;;
	 IEHS)
		stopIEHS
		;;
	*)
		 rfidic-get-message.sh RFID05050E "$items"
  esac
done
