#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2008
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: uninstallRFIDIC.sh	
##   Description: Uninstalls RFIDIC. Unconfigures WAS, MQ and Informix. 
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
. $SCRIPT_DIR/rfidic-env.sh


unconfigureMQ(){

# Unconfigure MQ
if [ -s "$MQ_HOME" ];then
	echo "Unconfiguring MQ..."
	run_command ${RFIDIC_HOME}/bin/rfidic-mq-cfg.sh -clean
fi
}

unconfigureWAS(){
if [ -s "$WAS_HOME" ];then
	echo "Unconfiguring WAS..."
	run_command ${RFIDIC_HOME}/bin/rfidic-was-cfg.sh -clean $credentials $was_runas_user
fi
}

unconfigureDB(){
# If DB is informix, unconfigure it. For Oracle and DB2, drop database explicitly
if [ "$DB_TYPE" = "INFORMIX" ];then
	if [ -s "$DBMS_HOME" ];then
		echo "Unconfiguring Informix..."
		run_command ${RFIDIC_HOME}/bin/rfidic-ifx-cfg.sh -clean
	fi
fi
}

deleteUser(){

if [ -z "$REMOVE_USER" ];then
	echo "Do you want to remove the rfidic user and group (y|n)?"
	read ans
	if [ "$ans" == "y" -o "$ans" == "Y" ];then
		userdel ${RFIDIC_USER}
		if [ "$OS" = "AIX" ];then
			rmgroup rfidic
		else
			groupdel rfidic
		fi
	else
		# Clear out entries from the rfidic user profile
		RFIDIC_PROFILE=".profile"
		if [ "$OS" = "Linux" ];then
			RFIDIC_PROFILE=".bash_profile"
		fi
		sed -e '/rfidic-env.sh/d' ${RFIDIC_HOME_DIR}/${RFIDIC_PROFILE} > ${RFIDIC_HOME_DIR}/profile.temp
		sed -e '/RFIDIC_HOME/d' ${RFIDIC_HOME_DIR}/profile.temp > ${RFIDIC_HOME_DIR}/profile.temp1
		mv -f ${RFIDIC_HOME_DIR}/profile.temp1 ${RFIDIC_HOME_DIR}/${RFIDIC_PROFILE}
		rm -f ${RFIDIC_HOME_DIR}/profile.temp
	fi
elif [ "$REMOVE_USER" = "Y" ] || [ "$REMOVE_USER" = "y" ];then
	userdel ${RFIDIC_USER}
	if [ "$OS" = "AIX" ];then
		rmgroup rfidic
	else
		groupdel rfidic
	fi	
else
	# Clear out entries from the rfidic user profile
	RFIDIC_PROFILE=".profile"
	if [ "$OS" = "Linux" ];then
		RFIDIC_PROFILE=".bash_profile"
	fi
	sed -e '/rfidic-env.sh/d' ${RFIDIC_HOME_DIR}/${RFIDIC_PROFILE} > ${RFIDIC_HOME_DIR}/profile.temp
	sed -e '/RFIDIC_HOME/d' ${RFIDIC_HOME_DIR}/profile.temp > ${RFIDIC_HOME_DIR}/profile.temp1
	mv -f ${RFIDIC_HOME_DIR}/profile.temp1 ${RFIDIC_HOME_DIR}/${RFIDIC_PROFILE}
	rm -f ${RFIDIC_HOME_DIR}/profile.temp
fi
}

deleteRFIDIC(){
	echo "Deleting RFIDIC files..."
	cd ..
	rm -rf ${RFIDIC_HOME}/bin
	rm -rf ${RFIDIC_HOME}/etc
	rm -rf ${RFIDIC_HOME}/ibm_help
	rm -rf ${RFIDIC_HOME}/lib
	rm -rf ${RFIDIC_HOME}/licenses
	rm -rf ${RFIDIC_HOME}/schemas
	rm -rf ${RFIDIC_HOME}/samples
	rm -rf ${RFIDIC_HOME}/VersionInfo
	rm -rf ${RFIDIC_HOME}/logs
}

usage(){
	echo "USAGE:./uninstallRFIDIC.sh -REMOVE_USER=<y|n> -RFIDIC_UNCONFIGURE=<components to be unconfigured> -was_runas_user=<WAS RunAs User> -was_admin_user=<WAS Admin User> -was_admin_password=<WAS Admin Password>"
}

for item in $@
        do
                if [ `expr match "$item" '-REMOVE_USER='` != 0 ];then
                        REMOVE_USER=`echo ${item#-REMOVE_USER=}`
		  		elif [ `expr match "$item" '-RFIDIC_UNCONFIGURE'` != 0 ];then
              	     RFIDIC_UNCONFIGURE=`echo ${item#-RFIDIC_UNCONFIGURE=}`
          		elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
              	     was_runas_user=`echo ${item#-was_runas_user=}`
		    	elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
              	     was_admin_user=`echo ${item#-was_admin_user=}`
           	    elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
		      	  	was_admin_password=`echo ${item#-was_admin_password=}`
		    	else
			  		usage 
              	fi
done

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
     	 echo "Enter the password for the $was_admin_user WebSphere Application Server (WAS) user:"
        stty -echo
	 read was_admin_password
	 stty echo
	 echo
fi

if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
fi

if [ -n "$was_runas_user" ];then
	  was_runas_user="-was_runas_user=$was_runas_user"
fi

# Determine which products need to be configured and configure accordingly.
if [ -z "$RFIDIC_UNCONFIGURE" ];then
	RFIDIC_UNCONFIGURE=was,db,mq
fi
components=`echo "$RFIDIC_UNCONFIGURE" | tr "," "\n" | tr "[a-z]" "[A-Z]" | sort` 
for item in $components
do
case "$item" in
        DB)
                unconfigureDB
		  db=$?
                ;;
        MQ)
		  unconfigureMQ
			mq=$?
		  ;;
        WAS)
                unconfigureWAS
			was=$?
                ;;
        *)
                echo "No such product: $item"
esac
done

deleteUser
deleteRFIDIC

if [ "$db" = "0" ];then
	comp="DB"
fi
if [ "$mq" = "0" ];then
	comp=$comp",MQ"
fi
if [ "$was" = "0" ];then
	comp=$comp",WAS"
fi
comp=`echo "$comp" | tr "," "\n" | tr "[a-z]" "[A-Z]" | sort`

echo "-------------------------------------------"
echo "RFIDIC has been successfully uninstalled. And, the following components have been unconfigured:\n$comp"
echo "-------------------------------------------"







