/**
 * Licensed Material - Property of IBM
 * (C) Copyright IBM Corp. 2006, 2008 - All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * 
 * (C) Copyright IBM Corp. and other(s) 2006, 2008  
 * 
 * The following sample of source code ("Sample Code") is owned by 
 * International Business Machines Corporation or one of its subsidiaries 
 * ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
 * modify, and distribute the Sample Code in any form without payment to IBM, 
 * for the purpose of assisting you in the development of your applications.
 *
 * The Sample Code is provided to you on an "AS IS" basis, without warranty of 
 * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
 * IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
 * not allow for the exclusion or limitation of implied warranties, so the 
 * above limitations or exclusions may not apply to you. IBM shall not be 
 * liable for any damages you suffer as a result of using, copying, modifying 
 * or distributing the Sample Code, even if IBM has been advised of the 
 * possibility of such damages.
 * 
 */
package com.ibm.rfidic.alerts.utils;

import java.io.File;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import com.ibm.rfidic.ws.clients.WebServiceManager;
import com.ibm.rfidic.ws.clients.alerts.Alert;
import com.ibm.rfidic.ws.clients.alerts.DeliveryMethod;
import com.ibm.rfidic.ws.clients.alerts.NotificationConfiguration;
import com.ibm.rfidic.ws.clients.alerts.Parameter;
import com.ibm.rfidic.ws.clients.alerts.ParameterValue;
import com.ibm.rfidic.ws.clients.alerts.SimpleConfiguration;
import com.ibm.rfidic.ws.clients.alerts.Subscription;
import com.ibm.rfidic.ws.clients.alerts.VoidHandler;
import com.ibm.rfidic.ws.clients.classloader.ClassloaderRegistry_PortType;
import com.ibm.rfidic.ws.clients.classloader.Jar;
import com.ibm.rfidic.ws.clients.classloader.JarListType;

/* The Alerts Utility provides functions that helps a Solution Developer
 * call functions to display, register and unregister Jars, Alerts, 
 * Delivery Methods, Notification Configurations and Subscriptions.  
 */
public class AlertsUtility 
{
  private WebServiceManager mgr = null;
  static private String GENERIC_MESSAGE_TEMPLATE = 
    "\n"                        + 
    "Event time: $timestamp\n"  +
    "Alert: $alert_name\n"      +
    "Subscriber: $subscriber\n" +
    "epc = $epc in event that triggered the alert in bizLocation = $bizLocation at eventTime = $eventTime\n";

	
  /* The constructor does not need to be altered by the Soluton Developer. */
  public AlertsUtility (String serverURL, String propertiesFile)
  {
    try
    {
      /* Create a file for our credentials if one does not exist already. */
      String fileName = "credential.properties";
      File file = new File(fileName);	
      if (file.exists() == false)
      {
        FileWriter fw = new FileWriter(fileName);
        fw.write("userName=user\n");
        fw.write("password=password\n");
        fw.flush();
        fw.close();
      }
    	
      mgr =  new WebServiceManager(serverURL,fileName);
    }
    catch(Exception e)
    {
       e.printStackTrace();
    }
  }
	
  /* The main function calls all the Web Serive methods to display, register and 
   * unregister Jars, Alerts, Delivery Methods, Notification Configurations and
   * Subscriptions.
   * The Solution Developer should only need to alter the contents of the main 
   * method to complete the actions they want to perform.  
   */
  public static void main (String arg[]) throws Exception
  {
    /*-----------------------------------------------------------------*/  
    /* 1. Initialize variables used to register artifacts etc.         */
    /*-----------------------------------------------------------------*/
    String rfidicUrl = "http://localhost:9080";   // URL of the RFIDIC server
    
    String alertsJar = "/home/rfidic/alerts.jar"; // Location of Jar file
    if (arg.length > 0)
    {
        rfidicUrl=arg[0];
    }
    System.out.println("rfidicUrl = "+rfidicUrl);
    
    if (arg.length == 2)
    {
        alertsJar=arg[1];
    }
    
    System.out.println("alertsJar = "+alertsJar);

    /* Edit these boolean to change behavior. */
    boolean jars            = true;
    boolean alerts          = true;
    boolean deliveryMethods = true;
    boolean notifConfigs    = true;
    boolean subscriptions   = true;
    
    /*-----------------------------------------------------------------*/
    /* 2. Create a utility object.                                     */
    /*-----------------------------------------------------------------*/  
    AlertsUtility util =  new AlertsUtility(rfidicUrl,"credential.properties");
	
    /*-----------------------------------------------------------------*/
    /* 3. These functions can be used for displaying, registering and  */
    /*    unregistering Jar files.                                     */
    /*    Warning: If one or more Jar files are unregistered then WAS  */
    /*    needs to be stopped and restarted for the unregistration to  */
    /*    take effect.                                                 */
    /*-----------------------------------------------------------------*/

    if (jars == true)
    {
      util.displayJars();
//      util.unregisterAllJars();
      util.registerJar(alertsJar,          // Location of Jar file
                       "Test Jar",         // Jar name  
                       "Sample Alerts");   // Solution name
    }

    /*-----------------------------------------------------------------*/
    /* 4. These functions can be used to register and unregister       */
    /*    Alerts.                                                      */
    /*-----------------------------------------------------------------*/
    if (alerts == true)
    {
      util.displayAlerts();
      util.unregisterAllAlerts();
      util.registerAlert("com.ibm.rfidic.alerts.nativealerts.ProductAtLocationAlert");
      util.registerAlert("com.ibm.rfidic.alerts.nativealerts.DuplicateCommissionAlert");
    }
		
    /*-----------------------------------------------------------------*/
    /* 5. These functions can be used to display, register and         */
    /*    unregister Delivery Methods.                                 */
    /*-----------------------------------------------------------------*/
    if (deliveryMethods == true)
    {
      util.displayDeliveryMethods();
      util.unregisterAllDeliveryMethods();
      util.registerDeliveryMethod("com.ibm.rfidic.alerts.delivery.FileDeliveryMethod");
      util.registerDeliveryMethod("com.ibm.rfidic.alerts.delivery.EmailDeliveryMethod");
    }

    /*-----------------------------------------------------------------*/
    /* 6. These functions can be used to display, register and         */
    /*    unregister Notification Configurations.                      */
    /*-----------------------------------------------------------------*/
    if (notifConfigs == true)
    {
      util.displayNotificationConfigurations();
      util.unregisterAllNotifications();

      /* Create a Hashmap containing preset parameters for the single 
       * delivery method of the notification configuration. The names 
       * of the parameters must be the same as the names specified in 
       * the Delivery Method class. Warning: If preset parameter values 
       * are provided here those parameters cannot be assigned values in 
       * the subscription when it is created.  */
      HashMap presetParameters =  new HashMap();
//      presetParameters.put("Delivery file name", 
//                           "/tmp/delivery_notifications.txt");
//      presetParameters.put("Message",            
//                           GENERIC_MESSAGE_TEMPLATE);

      util.registerSimpleNotification("File Notif Config",                                  // Name
                                      "File Notif Config Description",                      // Description
                                      "com.ibm.rfidic.alerts.delivery.FileDeliveryMethod",  // Delivery Method class  
                                      presetParameters);                                    // Preset Params hashmap

      presetParameters =  new HashMap();
//      presetParameters.put("To", "user1@company.com");
      presetParameters.put("From", "user2@company.com");
//      presetParameters.put("From personal", "rfidic");
//      presetParameters.put("CC", "user3@company.com");
//      presetParameters.put("Subject", "Duplicate Commission");
//      presetParameters.put("Record folder", "/home/rfidic/mail");
//      presetParameters.put("Message", GENERIC_MESSAGE_TEMPLATE);
            
      util.registerSimpleNotification("Email Notif Config",                                  // Name
                                      "Email Notif Config Description",                      // Description
                                      "com.ibm.rfidic.alerts.delivery.EmailDeliveryMethod",  // Delivery Method class 
                                      presetParameters);                                     // Preset Params hashmap
    }
		
    /*-----------------------------------------------------------------*/
    /* 7. These functions can be used to display, register and         */
    /*    unregister Subscriptions.                                    */
    /*-----------------------------------------------------------------*/
    if (subscriptions == true)
    {
//      util.displaySubscriptions();
//      util.unregisterAllSubscriptions();
//
//     /* Create and populate a hashmap of alert parameter values for the 
//       * subscription being created. */
//      HashMap alertParameters = new HashMap();
//      alertParameters.put("product", "Lawn Mowers");
//      alertParameters.put("location","Dock 5");
//		
//      /* Create and populate a hashmap of notification configuration 
//       * parameter values for the subscription being created. */
//      HashMap notifConfigParameters = new HashMap();
//      notifConfigParameters.put("File delivery method.Delivery file name",  
//    		                        "/home/rfidic/alert_log");
//      notifConfigParameters.put("File delivery method.Message", 
//    		                        GENERIC_MESSAGE_TEMPLATE);
//		
//      /* Create the subscription with following parameters: Subscription
//       * name; Subscription description; Subscriber; Alert class name;
//       * Notification name; Alert parameters and values hashmap; 
//       * Notification Configuration parameters and values hashmap. */ 
//      util.
//        registerSubscription("Sub1",                      
//                             "Subscription description",   
//                             "Guest",                     
//                             "com.ibm.rfidic.alerts.nativealerts.ProductAtLocationAlert",
//                             "File Notif Config",         
//                             alertParameters,             
//                             notifConfigParameters);
//
//      alertParameters = new HashMap();
//
//      util.registerSubscription("Sub2",                      
//              "Subscription description",   
//              "Guest",                     
//              "com.ibm.rfidic.alerts.nativealerts.DuplicateCommissionAlert",
//              "File Notif Config",         
//              alertParameters,             
//              notifConfigParameters);
//
//      notifConfigParameters = new HashMap();
//      notifConfigParameters.put("Email delivery method.To", "user1@company.com");
//      notifConfigParameters.put("Email delivery method.From", "user2@company.com");
//      notifConfigParameters.put("Email delivery method.From personal", "rfidic");
//notifConfigParameters.put("CC", "rfidic@rfidic-1.svl.ibm.com");
//      notifConfigParameters.put("Email delivery method.Subject", "Duplicate Commission");
//notifConfigParameters.put("Record folder", "/home/rfidic/mail");
//      notifConfigParameters.put("Email delivery method.Message", GENERIC_MESSAGE_TEMPLATE);
//
//      util.registerSubscription("Sub2",                      
//                             "Subscription description",   
//                             "Guest",                     
//                             "com.ibm.rfidic.alerts.nativealerts.DuplicateCommissionAlert",
//                             "Email Notif Config",         
//                             alertParameters,             
//                             notifConfigParameters);
//  util.setEnabledSubscription("Sub2", false);
    }
  }
	
  /*------------------------------------------------------------------------------------------------*/
  /* Methods below this point should not need to be changed.                                        */                         
  /*------------------------------------------------------------------------------------------------*/
  
  private void displayJars() throws Exception
  {
    System.out.println("\n\nJars:");
    System.out.println("=======");
		
    ClassloaderRegistry_PortType classLoaderRegistry = mgr.getClassloaderRegistry();
    Jar[] jarList = classLoaderRegistry.listJars().getJarList();
    for (int i=0; i< jarList.length; i++)
    {
      System.out.println("Jar :: " + i + "::" + jarList[i].getJarName());
    }
  }
  
  private void unregisterAllJars () throws Exception
  {
    ClassloaderRegistry_PortType classLoaderRegistry = mgr.getClassloaderRegistry();
    
    Jar[] jarLst = classLoaderRegistry.listJars().getJarList();
    for (int i=0; i< jarLst.length; i++)
    {
      System.out.println("Unregistering jar :: "+jarLst[i].getJarName());
      classLoaderRegistry.removeJar(jarLst[i].getJarName());
    } 
    System.out.println("All jars unregistered.");
    System.out.println("You will have to restart WAS for the unregistration to take effect.");
  }
  
  private void registerJar(String fileLocation, String jarName, String solution) throws Exception
  {
    ClassloaderRegistry_PortType classLoaderRegistry = mgr.getClassloaderRegistry();
		
    System.out.println("Registering new Jar");
    Jar[] jarFile =  new Jar[1];
    jarFile[0] = new Jar();
    jarFile[0].setJarLocation("file:"+fileLocation);
    jarFile[0].setJarName(jarName);
    jarFile[0].setSolution(solution);
    JarListType jarList = new JarListType();
    jarList.setJarList(jarFile);
    classLoaderRegistry.installJar(jarList);
    System.out.println("Jar registered");
  }
	
  private void displayAlerts()throws Exception
  {
    System.out.println("\n\nAlerts:");
    System.out.println("=======");
	    
    final Alert[] alerts = mgr.getAlertsRegistry().getAll(new VoidHandler());
    if (alerts != null)
    {
      final List list = new ArrayList(Arrays.asList(alerts));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Alert alert = (Alert) iterator.next();
        System.out.println("id: " + alert.getId() + ", class name: " + alert.getClassName());
      }
    }
  }
	
  private void unregisterAllAlerts()throws Exception 
  {
    final Alert[] alerts = mgr.getAlertsRegistry().getAll(new VoidHandler());
    if (alerts != null)
    {
      final List list = new ArrayList(Arrays.asList(alerts));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Alert alert = (Alert) iterator.next();
        System.out.println("Unregistering alert ::: id: " + alert.getId() + ", class name: " + alert.getClassName());
        mgr.getAlertsRegistry().delete(alert.getId());
      }
    }
    System.out.println("All alerts unregistered.");
  }
	
  private void registerAlert (String alertClassName) throws Exception 
  {
    Alert a = mgr.getAlertsRegistry().add(alertClassName);
    mgr.getAlertsRegistry().setEnabled(a.getId(), true);
    System.out.println("Alert " + alertClassName + " registered.");
  }
	
  private void displayDeliveryMethods()throws Exception 
  {
    System.out.println("\n\nDelivery methods:");
    System.out.println("=================");
	    
    final DeliveryMethod[] deliveryMethods = mgr.getDeliveryMethodsRegistry().getAll(new VoidHandler());
    if (deliveryMethods != null)
    {
      final List list = new ArrayList(Arrays.asList(deliveryMethods));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final DeliveryMethod deliveryMethod = (DeliveryMethod) iterator.next();
        System.out.println("id: " + deliveryMethod.getId() + ", class name: " + deliveryMethod.getClassName());
      }
    }
  }

  private void unregisterAllDeliveryMethods () throws Exception 
  {
    final DeliveryMethod[] deliveryMethods = mgr.getDeliveryMethodsRegistry().getAll(new VoidHandler());
    if (deliveryMethods != null)
    {
      for (int i = 0; i < deliveryMethods.length; i++)
      {
        final DeliveryMethod delMethod = deliveryMethods[i];
        System.out.println("Unregistering delivery method ::: id: " + delMethod.getId() + ", class name: " + delMethod.getClassName());
        mgr.getDeliveryMethodsRegistry().delete(delMethod.getId());
      }
    }
    System.out.println("All delivery methods unregistered.");
  }
	
  private void registerDeliveryMethod(String delMethodClassName) throws Exception
  {
    final DeliveryMethod deliveryMethod = mgr.getDeliveryMethodsRegistry().add(delMethodClassName);
    mgr.getDeliveryMethodsRegistry().setEnabled(deliveryMethod.getId(), true);
    System.out.println("Delivery Method " + delMethodClassName + " registered.");
  }
	
  private void displayNotificationConfigurations() throws Exception
  {
    System.out.println("\n\nNotification configurations:");
    System.out.println("============================");
		
    final NotificationConfiguration[] notificationConfigurations = mgr.getNotificationConfigurationsRegistry().getAll(new VoidHandler());
    if (notificationConfigurations != null)
    {
      final List list = new ArrayList(Arrays.asList(notificationConfigurations));

      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final NotificationConfiguration notificationConfiguration = (NotificationConfiguration) iterator.next();
        System.out.println("id: " + notificationConfiguration.getId() + ", class name: "
                           + notificationConfiguration.getClassName());
        System.out.println("XML:\n" + notificationConfiguration.getXmlContent());

        final Parameter[] parameters = notificationConfiguration.getParameters();
        if (parameters != null)
        {
          for (int i = 0; i < parameters.length; i++)
          {
            System.out.println("Parameter " + (i + 1) + ":");
            System.out.println("  Name: " + parameters[i].getName());
            System.out.println("  Type: " + parameters[i].getType());
          }
        }
      }
    }
  }	
	
  private void unregisterAllNotifications() throws Exception 
  {
    final NotificationConfiguration[] notificationConfigurations = mgr.getNotificationConfigurationsRegistry().getAll(new VoidHandler());
    if (notificationConfigurations != null)
    {
      final List list = new ArrayList(Arrays.asList(notificationConfigurations));

      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final NotificationConfiguration nc = (NotificationConfiguration) iterator.next();
        System.out.println("Unregistering notification config ::: id: " + nc.getId() + ", name: " + nc.getName());
        mgr.getNotificationConfigurationsRegistry().delete(nc.getId());
      }
    }
    System.out.println("All notification configurations unregistered.");
  }
	
  private void registerSimpleNotification(String notificationName,
                                          String notificationDescription, 
                                          String deliveryMethodClassName,
                                          HashMap presetParameters) throws Exception 
  {
    DeliveryMethod deliveryMethod = null;
    deliveryMethod = mgr.getDeliveryMethodsRegistry().findByClass(deliveryMethodClassName);
    final ParameterValue[] presetParameterValues = convertHashMapToParameterArray(presetParameters);

    final SimpleConfiguration simpleConfiguration = new SimpleConfiguration();
    simpleConfiguration.setDeliveryMethodId(deliveryMethod.getId());
    simpleConfiguration.setName(notificationName);
    simpleConfiguration.setDescription(notificationDescription);
    simpleConfiguration.setValues(presetParameterValues);

    mgr.getNotificationConfigurationsRegistry().addSimpleConfiguration(simpleConfiguration);
    System.out.println("Notification Configuration " + notificationName + " registered.");
  }
	
  private void displaySubscriptions() throws Exception 
  {
    final Subscription[] subscriptions = mgr.getSubscriptionsRegistry().getAll(new VoidHandler());
    System.out.println("\n\nSubscriptions:");
    System.out.println("==============");
    if (subscriptions != null)
    {
      final List list = new ArrayList(Arrays.asList(subscriptions));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Subscription subscription = (Subscription) iterator.next();
        System.out.println("\nid: " + subscription.getId() + ", name: " + subscription.getName() + ", subscriber: "
            + subscription.getSubscriber() + ", alert id: " + subscription.getAlertId()
            + ", notification configuration id: " + subscription.getNotificationConfigurationId());

        final ParameterValue[] alertParameterValues = subscription.getAlertValues();
        if (alertParameterValues != null)
        {
          System.out.println("Alert parameter values:");
          System.out.println("-----------------------");
          for (int i = 0; i < alertParameterValues.length; i++)
          {
            System.out.println("Value " + (i + 1) + ":");
            System.out.println("  Name: " + alertParameterValues[i].getParameterName());
            System.out.println("  Value: " + alertParameterValues[i].getValue());
          }
        }

        final ParameterValue[] notificationConfigurationParameterValues = 
        	 subscription.getNotificationConfigurationValues();
         
        if (notificationConfigurationParameterValues != null)
        {
          System.out.println("Notification configuration parameter values:");
          System.out.println("--------------------------------------------");
          for (int i = 0; i < notificationConfigurationParameterValues.length; i++)
          {
            System.out.println("Value " + (i + 1) + ":");
            System.out.println("  Name: " + notificationConfigurationParameterValues[i].getParameterName());
            System.out.println("  Value: " + notificationConfigurationParameterValues[i].getValue());
          }
        }
      }
    }
  }

  private void unregisterAllSubscriptions() throws Exception
  {
    final Subscription[] subscriptions = mgr.getSubscriptionsRegistry().getAll(new VoidHandler());
    if (subscriptions != null)
    {
      final List list = new ArrayList(Arrays.asList(subscriptions));
	      
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Subscription sub = (Subscription) iterator.next();
        System.out.println("Unregistering subscriptions ::: id: " + sub.getId() + ", name: " + sub.getName());
        mgr.getSubscriptionsRegistry().delete(sub.getId()); 
      }
    }
    System.out.println("All subscriptions unregistered.");
  }
  
  private void registerSubscription(String subscriptionName,
                                    String subscriptionDescription,
                                    String subscriptionSubscriber,                                    
                                    String alertClassName, 
                                    String notifConfigName,
                                    HashMap alertParameters,
                                    HashMap notifConfigParameters) throws Exception
  {
    Alert a = mgr.getAlertsRegistry().findByClass(alertClassName);
    NotificationConfiguration n = mgr.getNotificationConfigurationsRegistry().findByName(notifConfigName);
		
    final Subscription subscription = new Subscription();
    subscription.setEnabled(true);
    subscription.setName(subscriptionName);
    subscription.setDescription(subscriptionDescription);
    subscription.setSubscriber(subscriptionSubscriber);
    subscription.setAlertId(a.getId());
    subscription.setNotificationConfigurationId(n.getId());
    Calendar calendar = new GregorianCalendar();
    calendar.setTime(new Date());
    subscription.setDate(calendar);

    /* Create an array of Alert parameters and values 
     * and add the array to our subscription. */
	  final ParameterValue[] alertParams = convertHashMapToParameterArray(alertParameters);
    subscription.setAlertValues(alertParams);
	
    /* Create an array of Notification Configuration parameters and values 
     * and add the array to our subscription. */
    final ParameterValue[] ncParams = convertHashMapToParameterArray(notifConfigParameters);
    subscription.setNotificationConfigurationValues(ncParams);
    
    /* Finally add the subscription to the subscription registry. */
    mgr.getSubscriptionsRegistry().add(subscription);
    
    System.out.println("Subscription:: " + subscriptionName + " registered.");
  }

  private void setEnabledSubscription(String subName, boolean status) throws Exception
  {
    final Subscription[] subscriptions = mgr.getSubscriptionsRegistry().getAll(new VoidHandler());

    for (int i = 0; i < subscriptions.length; i++)
    {
      if (subscriptions[i].getName().equals(subName))
      {
        mgr.getSubscriptionsRegistry().setEnabled(subscriptions[i].getId(), status);    
      }
    }
  }
  
  private ParameterValue [] convertHashMapToParameterArray(HashMap parameters)
  {
    final Set paramNames = parameters.keySet();
    final ParameterValue[] parameterValues = new ParameterValue[paramNames.size()];

    int i = 0;
		
    for (Iterator iterator = paramNames.iterator(); iterator.hasNext();)
    {
      final String paramName  = (String)iterator.next();
      final String paramValue = (String)parameters.get(paramName); 
	        
      parameterValues[i] = new ParameterValue();
      parameterValues[i].setParameterName(paramName);
      parameterValues[i].setValue(paramValue);
      i++;
    }
    return parameterValues;
  }

  private void removeAlert(String alertClassName) throws Exception 
  {
    Alert a = mgr.getAlertsRegistry().findByClass(alertClassName);
    mgr.getAlertsRegistry().delete(a.getId());
  }
	
  private void removeDeliveryMethid(String deliveryMethodName) throws Exception 
  {
    final DeliveryMethod[] delMethods = mgr.getDeliveryMethodsRegistry().getAll(new VoidHandler());
    final List list = new ArrayList(Arrays.asList(delMethods));
    
    for (Iterator iterator = list.iterator(); iterator.hasNext();)
    {
      final DeliveryMethod dm = (DeliveryMethod) iterator.next();
      if (dm.getName().equalsIgnoreCase(deliveryMethodName))
      {
        mgr.getDeliveryMethodsRegistry().delete(dm.getId()); 
        break;
      }
    }  		
  }
  
  private void removeNotification(String notificationName) throws Exception 
  {
    final NotificationConfiguration notificationConfiguration = mgr.getNotificationConfigurationsRegistry().findByName(notificationName);
    mgr.getNotificationConfigurationsRegistry().delete(notificationConfiguration.getId());
  }

  private void removeSubscription(String subscriptionName) throws Exception
  {
    final Subscription[] subscriptions = mgr.getSubscriptionsRegistry().getAll(new VoidHandler());
    final List list = new ArrayList(Arrays.asList(subscriptions));
    
    for (Iterator iterator = list.iterator(); iterator.hasNext();)
    {
      final Subscription subscription = (Subscription) iterator.next();
      if (subscription.getName().equalsIgnoreCase(subscriptionName))
      {
        mgr.getSubscriptionsRegistry().delete(subscription.getId()); 
        break;
      }
    }  		
  }
}
