#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# (C) COPYRIGHT International Business Machines Corp. 2007, 2009
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# 
# upgradeFP.sh - applies the passed tar on the current version of TS
# This script will only apply the binaries, migrate the EARs so that the security settings are retained. 
# And restart the TS. Assumption is that - there are no DB,MQ,WAS changes in the Fix Pack that is applied.
# It will retain the earlier configuration settings [in RFIDICServer.xml and rfidic-env.sh]
#	USAGE: ./upgradeFP.sh -RFIDIC_HOME=<ITS install directory> -RFIDIC_BUILD_PATH=<Path to the TS tar to be applied>
#	                        [-BACKUP_OLD_INSTALLATION=Y]
#	                        [-was_runas_user=<value>]
#	                        [-was_admin_user=<value>]
#	                        [-was_admin_password=<value>]
#							[-help - optional, to print usage]
###############################################################################################################

sDir=`dirname ${0}`
scriptDir=`cd $sDir | pwd`

CP="/bin/cp"
RM="/bin/rm -f"
ECHO="echo"
AWK="awk -F ".""
AWK_EQUAL="awk -F "=""
RFIDIC_PROFILE=".profile"
groups="id -Gn"

OS=`/bin/uname`
case $OS in
	AIX)
		HOSTNAME=`hostname -s`
		HOSTNAMEFULL=`hostname`	
		;;
	Linux)
		ECHO="echo -e"
		RFIDIC_PROFILE=".bash_profile"
		HOSTNAME=`hostname -s`
		HOSTNAMEFULL=`hostname -f`
		CP="/bin/cp --reply=yes"
		;;
	SunOS)
		AWK="awk -F."
		AWK_EQUAL="awk -F="
		HOSTNAME=`hostname`
		HOSTNAMEFULL=`/usr/sbin/check-hostname | awk '{print($7)}'`
		groups="/usr/xpg4/bin/id -Gn"
		;;
esac

pause()
{
	echo_msg "\nPress <<ENTER>> key to continue."
	read
}

usage(){
		echo_msg "\nUSAGE: ./upgradeFP.sh -RFIDIC_HOME=<ITS install directory> -RFIDIC_BUILD_PATH=<Path to the TS tar to be applied>"
	echo_msg "	USAGE: ./upgradeFP.sh -RFIDIC_HOME=<ITS install directory> -RFIDIC_BUILD_PATH=<Path to the TS tar to be applied>"
	echo_msg "	                        [-BACKUP_OLD_INSTALLATION=<Y|N>] optional, takes a backup of binaries if Y is passed under TS Home as TS2.0_backup.tar; user will be prompted if not passed"
	echo_msg "	                        [-was_runas_user=<value>] optional, required only if WAS run-as user is different from $RFIDIC_USER, defaults to $RFIDIC_USER"
	echo_msg "	                        [-was_admin_user=<value>] optional, required only is security is turned on"
	echo_msg "	                        [-was_admin_password=<value>] optional, required only if security is turned on"
	echo_msg "                        [-help - optional to print usage]"
	
	exit 1
}

run_command(){
        command="$*"
        "$@"
        retcode=$?
        if [ "$retcode" -ne 0 ]
        then
                echo_msg "\nError occured while running command: $command"
                exit $retcode
        fi
}

echo_msg(){
   $ECHO $1 | tee -a $LOG
}

runUserCommand()
{
        user=$1
        shift
        command="$*"
        retcode=1
        COUNT=0
        echo_msg "If prompted - enter the password for $user"
        while [ $retcode -ne 0 ] && [ $COUNT -lt 2 ]
        do

                if [ "$OS" = "SunOS" ];then
                        /bin/su - ${user} -c "${command}"
                        retcode=$?
                elif [ "$OS" = "AIX" ];then
                        /bin/su - ${user} "-c ${command}"
                        retcode=$?
                else
                        /bin/su - -c "${command}" ${user}
                        retcode=$?
                fi
              COUNT=`expr $COUNT + 1`
        done
        return $retcode
}

updateBinaries(){
	# Extract the files from the build
		
	run_command cd ${RFIDIC_HOME}
	run_command tar -xvf ${RFIDIC_BUILD_PATH} >> $LOG
		
	# Create backup of new Metadata and configuration files
	run_command mv -f $RFIDIC_HOME/etc/EPCISDocumentMetaData.xml $RFIDIC_HOME/etc/EPCISDocumentMetaData.xml.vFP
	run_command mv -f $RFIDIC_HOME/etc/ProductMetaData.xml $RFIDIC_HOME/etc/ProductMetaData.xml.vFP
	run_command mv -f $RFIDIC_HOME/etc/LocationMetaData.xml $RFIDIC_HOME/etc/LocationMetaData.xml.vFP
	run_command mv -f $RFIDIC_HOME/etc/RFIDICServer.xml $RFIDIC_HOME/etc/RFIDICServer.xml.vFP
	run_command mv -f $RFIDIC_HOME/etc/Capture.xml $RFIDIC_HOME/etc/Capture.xml.vFP
	run_command mv -f $RFIDIC_HOME/etc/SolutionQueries.xml $RFIDIC_HOME/etc/SolutionQueries.xml.vFP
	run_command mv -f $RFIDIC_HOME/etc/log.xml $RFIDIC_HOME/etc/log.xml.vFP
	run_command mv -f $RFIDIC_HOME/bin/rfidic-env.sh $RFIDIC_HOME/etc/rfidic-env.sh.vFP

	# Restore the original Metadata and configuration files
	run_command mv -f $RFIDIC_HOME/etc/EPCISDocumentMetaData.xml.bck $RFIDIC_HOME/etc/EPCISDocumentMetaData.xml
	run_command mv -f $RFIDIC_HOME/etc/ProductMetaData.xml.bck $RFIDIC_HOME/etc/ProductMetaData.xml
	run_command mv -f $RFIDIC_HOME/etc/LocationMetaData.xml.bck $RFIDIC_HOME/etc/LocationMetaData.xml
	run_command mv -f $RFIDIC_HOME/etc/RFIDICServer.xml.bck $RFIDIC_HOME/etc/RFIDICServer.xml
	run_command mv -f $RFIDIC_HOME/etc/Capture.xml.bck $RFIDIC_HOME/etc/Capture.xml
	run_command mv -f $RFIDIC_HOME/etc/SolutionQueries.xml.bck $RFIDIC_HOME/etc/SolutionQueries.xml
	run_command mv -f $RFIDIC_HOME/etc/log.xml.bck $RFIDIC_HOME/etc/log.xml
	run_command mv -f $RFIDIC_HOME/bin/rfidic-env.sh.bck $RFIDIC_HOME/bin/rfidic-env.sh
	
	
	# Find the user who is running this script. This user has administrative privileges
	ID=`id`
	ORIG_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`
	# Dynamically fetch the primary group of the above user
	ORIG_GROUP=`expr "$ID" : ".*gid=[0-9]*(\([^)]*\)*"`

	# Change ownership of files
	echo_msg "\nSetting file permission"
	run_command chown ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}
	run_command chown -R ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}/bin
	run_command chown -R ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}/lib
	run_command chown -R ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}/etc
	run_command chown -R ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}/samples
	run_command chown -R ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}/schemas
	run_command chown -R ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}/licenses
	run_command chown -R ${RFIDIC_USER}:${RFIDIC_GROUP} ${RFIDIC_HOME}/VersionInfo
	run_command chown -R ${ORIG_USER}:${ORIG_GROUP} ${RFIDIC_HOME}/bin/rfidic-was-cfg.sh
	run_command chown -R ${ORIG_USER}:${ORIG_GROUP} ${RFIDIC_HOME}/bin/rfidic-mq-cfg.sh
	run_command chown -R ${ORIG_USER}:${ORIG_GROUP} ${RFIDIC_HOME}/bin/rfidic-ifx-cfg.sh
	run_command chown -R ${ORIG_USER}:${ORIG_GROUP} ${RFIDIC_HOME}/bin/rfidic-default-cfg.sh
	run_command chown -R ${ORIG_USER}:${ORIG_GROUP} ${RFIDIC_HOME}/bin/uninstallRFIDIC.sh
	run_command rm -rf ${RFIDIC_HOME}/scripts
	# Set permissions
	run_command chmod -R 755 ${RFIDIC_HOME}/bin
	run_command chmod 554 ${RFIDIC_HOME}/bin/*.sh
	run_command chmod 750 ${RFIDIC_HOME}/bin/rfidic-env.sh
	run_command chmod -R 444 ${RFIDIC_HOME}/etc
	run_command chmod 644 ${RFIDIC_HOME}/etc/*.xml
	run_command chmod 640 ${RFIDIC_HOME}/etc/RFIDICServer.xml
	run_command chmod -R 444 ${RFIDIC_HOME}/lib
	run_command chmod -R 444 ${RFIDIC_HOME}/samples
	run_command chmod -R 444 ${RFIDIC_HOME}/schemas
	run_command chmod -R 444 ${RFIDIC_HOME}/licenses
	run_command chmod -R 444 ${RFIDIC_HOME}/VersionInfo
	# List all the sub-directories and set permission
	run_command chmod 755 ${RFIDIC_HOME}
	run_command chmod 755 ${RFIDIC_HOME}/bin
	run_command chmod 755 ${RFIDIC_HOME}/bin/WAS/ears/*.ear
	run_command chmod 755 ${RFIDIC_HOME}/etc
	run_command chmod 755 ${RFIDIC_HOME}/lib
	run_command chmod 755 ${RFIDIC_HOME}/samples
	run_command chmod -R 755 ${RFIDIC_HOME}/samples/alerts
	run_command chmod 444 ${RFIDIC_HOME}/samples/alerts/src/com/ibm/rfidic/alerts/coral8/*
	run_command chmod 444 ${RFIDIC_HOME}/samples/alerts/src/com/ibm/rfidic/alerts/delivery/*
	run_command chmod 444 ${RFIDIC_HOME}/samples/alerts/src/com/ibm/rfidic/alerts/message/builder/*
	run_command chmod 444 ${RFIDIC_HOME}/samples/alerts/src/com/ibm/rfidic/alerts/nativealerts/*
	run_command chmod 444 ${RFIDIC_HOME}/samples/alerts/src/com/ibm/rfidic/alerts/templates/*
	run_command chmod 444 ${RFIDIC_HOME}/samples/alerts/src/com/ibm/rfidic/alerts/utils/*
	run_command chmod 555 ${RFIDIC_HOME}/samples/alerts/bin/*
	run_command chmod 755 ${RFIDIC_HOME}/samples/audit
	run_command chmod 755 ${RFIDIC_HOME}/samples/mdm
	run_command chmod 755 ${RFIDIC_HOME}/schemas
	run_command chmod 755 ${RFIDIC_HOME}/licenses
	run_command chmod 755 ${RFIDIC_HOME}/VersionInfo
	
	echo_msg "\n\n----------Updating Binaries - Done------"
}

backupInstallation(){
	run_command cd $RFIDIC_HOME
	run_command tar -cvf RFIDIC_backup.tar bin etc lib licenses samples schemas VersionInfo >> $LOG
}

backupFiles(){
run_command cp $RFIDIC_HOME/etc/EPCISDocumentMetaData.xml $RFIDIC_HOME/etc/EPCISDocumentMetaData.xml.bck
run_command cp $RFIDIC_HOME/etc/Capture.xml $RFIDIC_HOME/etc/Capture.xml.bck
run_command cp $RFIDIC_HOME/etc/SolutionQueries.xml $RFIDIC_HOME/etc/SolutionQueries.xml.bck
run_command cp $RFIDIC_HOME/etc/log.xml $RFIDIC_HOME/etc/log.xml.bck
run_command cp $RFIDIC_HOME/etc/LocationMetaData.xml $RFIDIC_HOME/etc/LocationMetaData.xml.bck
run_command cp $RFIDIC_HOME/etc/ProductMetaData.xml $RFIDIC_HOME/etc/ProductMetaData.xml.bck
run_command cp $RFIDIC_HOME/etc/RFIDICServer.xml $RFIDIC_HOME/etc/RFIDICServer.xml.bck
run_command cp $RFIDIC_HOME/bin/rfidic-env.sh $RFIDIC_HOME/bin/rfidic-env.sh.bck
run_command cp $RFIDIC_HOME/VersionInfo/versionInfo.properties $RFIDIC_HOME/VersionInfo/versionInfo.properties.bck
run_command cp $RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.ejb.audit.ear $RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.ejb.audit.ear.bck
run_command cp $RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.ear $RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.ear.bck
run_command cp $RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.ui.ear $RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.ui.ear.bck
}

reinstallEARs(){
	# recreate the shared library that contains the RFIDIC jars 
	CONFIG_OPTION="configure"
	RFIDIC_JARS_PATH_PREFIX="${RFIDIC_HOME}/lib/"
	RFIDIC_JARS=`cd $RFIDIC_HOME/lib;ls *.jar`
	for jar in $RFIDIC_JARS
	do
	  	RFIDIC_JARS_PATH=$RFIDIC_JARS_PATH$RFIDIC_JARS_PATH_PREFIX$jar:
	done
	echo_msg "\nUpdating the shared library..."
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_credentials -f $RFIDIC_HOME/bin/jacl/setLibrary.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME RFIDIC_UI_LIB $RFIDIC_JARS_PATH "Shared libraries for RFIDIC UI applications." >> $LOG
	
	# Re-install applications
	START_OPTION=no_start
	echo_msg "\nRe-installing application $RFAPP_NAME..."
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_credentials -f $RFIDIC_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $RFAPP_LOCATION $RFAPP_NAME $START_OPTION $RFIDIC_HOME >> $LOG

	###  Re-install UI Application ###
	echo_msg "\nRe-installing application $UIAPP_NAME..."
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_credentials -f $RFIDIC_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $UIAPP_LOCATION $UIAPP_NAME $START_OPTION >> $LOG


	runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/stopRFIDIC.sh -components=was,mq,capture $credentials
	retCode=$?
	if [ "$retCode" != 0 -a "$retCode" != 246 ];then
		echo_msg "\nThe stopRFIDIC.sh command returned a non-zero code $retCode. You might need to restart WAS manually."
	fi

	if [ -z "$was_runas_user" ];then
       	runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/startRFIDIC.sh -components=was,mq,capture $credentials >> $LOG
	else
		runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/startRFIDIC.sh -components=was,mq,capture $credentials $was_runas >> $LOG
	fi
	retCode=$?
	if [ "$retCode" != 0 -a "$retCode" != 127 ];then
		echo_msg "\nThe startRFIDIC.sh command returned a non-zero code $retCode. You might need to restart WAS manually."
	fi
	echo_msg "\n\n---------- Re-install of EARs Succesful -------------"
	return 0
}


# Main starts here
for item in $@
        do
            if [ `expr match "$item" '-BACKUP_OLD_INSTALLATION='` != 0 ];then
                 BACKUP_OLD_INSTALLATION=`$ECHO ${item#-BACKUP_OLD_INSTALLATION=}`
            elif [ `expr match "$item" '-RFIDIC_HOME='` != 0 ];then
                 RFIDIC_HOME=`$ECHO ${item#-RFIDIC_HOME=}`
		    elif [ `expr match "$item" '-RFIDIC_BUILD_PATH='` != 0 ];then
                 RFIDIC_BUILD_PATH=`$ECHO ${item#-RFIDIC_BUILD_PATH=}`
		    elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
	             was_runas_user=`$ECHO ${item#-was_runas_user=}`
		    elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
    	         	was_admin_user=`$ECHO ${item#-was_admin_user=}`
       	    elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
			     was_admin_password=`$ECHO ${item#-was_admin_password=}`
       	    elif [ `expr match "$item" '-help'` != 0 ];then
				 usage 
				 exit
		    else
				 echo "Unidentified argument passed" 
				 usage 
				 exit
            fi
done

if [ -z "$LOG" ];then
	LOG=${scriptDir}/upgradeFP.log
fi

if [ -f "$LOG" ];then
	index=0
	while [ "$index" -lt "10" ]
        do
            index=`expr $index + 1`
        	LOG=${scriptDir}/upgradeFP$index.log
			if [ -f "$LOG" ];then
				echo " "
	        else
			    index=100
			fi
        done
	if [ -f "$LOG" ];then
		echo "Please delete or archive all old log files and then continue"
		pause
	fi
fi

# Check if the RFIDIC_HOME is correct
if [ -z "$RFIDIC_HOME" ]; then
       	RFIDIC_HOME=/opt/ibm/WebSphere/RFIDICv2.0
		echo_msg "\n------------------------------------------------------"
        echo_msg "RFIDIC_HOME was not set in the environment. Setting it to $RFIDIC_HOME."
		echo_msg "------------------------------------------------------"
fi
if  [ ! -d $RFIDIC_HOME"/etc" ]
then
	echo_msg "\n------------------------------------------------------"
    echo_msg "$RFIDIC_HOME is not a valid IBM InfoSphere Traceability Server installation directory. Exiting upgradation process."
	echo_msg "------------------------------------------------------"
    usage
fi

echo_msg "\nVerifying available diskspace..."

if [ "$OS" = "SunOS" ];then
	 DF_OPTIONS="-k"
else
	 DF_OPTIONS="-Pk"
fi

SPACE=`df $DF_OPTIONS "$RFIDIC_HOME" | tail -1 | awk '{ print $4 }'`
TMP_SPACE=`df $DF_OPTIONS /tmp | tail -1 | awk '{ print $4 }'`

#Check to ensure 1 GB free space is available for migration 
if [ "$SPACE" -lt 1048576 ]
then
		clear
		echo_msg "\nIBM InfoSphere Traceability Server requires 1.5 GB for Migration"
		exit 1
fi
#Check to ensure 500 MB free space is available in /tmp for installation 
if [ "$TMP_SPACE" -lt 512000 ]
then
		clear
		echo_msg "Install >> Platform Verification >> Error"
		echo_msg "--------------------------------------------------"
		echo_msg "\nIBM InfoSphere Traceability Server requires 500 MB in /tmp for migration"
		exit_install
fi
echo_msg "Diskspace verified."
sleep 2


# include the RFIDIC environment settings
. $RFIDIC_HOME/bin/rfidic-env.sh

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
   	 echo_msg "\nEnter the password for the $was_admin_user WebSphere Application Server (WAS) user:"
     stty -echo
	 read was_admin_password
	 stty echo
fi

if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
     credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
	 wsadmin_credentials="-conntype SOAP -user $was_admin_user -password $was_admin_password"
fi
if [ -z "$was_runas_user" ];then
	was_runas_user=${RFIDIC_USER}
fi

if [ -n "$was_runas_user" ];then
	  was_runas="-was_runas_user=$was_runas_user"
fi

if  [ -z "$RFIDIC_BUILD_PATH" ]
then
	echo_msg "\n------------------------------------------------------"
    echo_msg "RFIDIC_BUILD_PATH was not set in the environment. IBM InfoSphere Traceability Server installables not found."
	echo_msg "Exiting upgradation process."
	echo_msg "------------------------------------------------------"
   usage
fi

if [ -z "$BACKUP_OLD_INSTALLATION" ];then
	echo_msg "\nDo you want to backup the existing TS binaries? (y/n)"
	read ans
	if [ "$ans" = "y" -o "$ans" = "Y" ];then
		backupInstallation
	fi
elif [ "$BACKUP_OLD_INSTALLATION" = "Y" -o "$BACKUP_OLD_INSTALLATION" = "y" ]
then
	backupInstallation
fi

backupFiles
updateBinaries
reinstallEARs
unset CLASSPATH
unset pathdone
. ${RFIDIC_HOME}/bin/rfidic-env.sh
	
	echo_msg "\n---------------------------------------------------"
	echo_msg "IBM InfoSphere Traceability Server Fix Pack was installed successfully."
	echo_msg "---------------------------------------------------"
exit 0
